/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 6.5                   *
*********************************************************************************
* Id: fxarchive.h,                                2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/
#ifndef FXARCHIVE_H
#define FXARCHIVE_H

#include "config.h"

#ifndef  FXMMPROGRESSBAR_H
 #include "fxmmProgressbar.h"
#endif
#ifndef  FXMMFILELIST_H
 #include "fxmmFileList.h"
#endif

//! forward declarations for persistent classes
class DiskMapDialog;
class fxmmExtractDialog;

class ArchiveDialog : public FXMainWindow
{
  FXDECLARE(ArchiveDialog)

private:
  ArchiveDialog(){};
  ArchiveDialog(const ArchiveDialog&){};

protected:
  //! declare dialog for persistent classes
  DiskMapDialog *diskmapdialog;
  fxmmExtractDialog *fxmmextractdialog;

  // drag types
  FXDragType  urilistType; // FXMM list drag type
  FXDragType  actionType;  // FXMM action drag type
  FXString    clipboard;   // our clipboard

  FXIcon *logoicon;
  FXIcon *logominiicon;
  // main
  FXIcon *quiticon;
  FXIcon *extracticon;
  FXIcon *commandicon;
  FXIcon *compressicon1;
  FXIcon *compressicon2;
  FXIcon *compressicon3;
  FXIcon *compressicon4;
  FXIcon *compressicon5;
  // menu
  FXIcon *compressicons1;
  FXIcon *compressicons2;
  FXIcon *compressicons3;
  FXIcon *compressicons4;
  FXIcon *compressicons5;
  FXIcon *extracticons;
  FXIcon *commandicons;
  FXIcon *m_refreshicon;
  FXIcon *m_terminalicon;
  FXIcon *m_consoleicon;
  FXIcon *m_renamediricon;
  FXIcon *m_renameicon;
  FXIcon *m_appendicon;
  FXIcon *m_cuticon;
  FXIcon *m_copyicon;
  FXIcon *m_pasteicon;
  FXIcon *m_deleteicon;
  // virtual icon
  FXIcon *deviceicon;
  // devices
  FXIcon *m_removableicon;
  FXIcon *m_harddiskicon;
  FXIcon *m_isodiskicon;
  FXIcon *m_floppydiskicon;
  // dialog
  FXIcon *accepticon;
  FXIcon *cancelicon;
  // filelist headers
  FXIcon *m_usricon;
  FXIcon *m_grpicon;
  FXIcon *m_prmicon;
  FXIcon *m_dimicon;
  FXIcon *m_daticon;
  FXIcon *m_diricon;

  FXButton *button_ta;
  FXButton *button_gz;
  FXButton *button_bz;
  FXButton *button_zi;
  FXButton *button_7z;
  FXButton *button_xz;
  FXButton *button_lz;
  FXButton *button_ex;
  FXButton *button_cm;
  FXButton *button_qu;

  FXMenuBar *menubar;

  FXMenuPane *menu_arrange;
  FXMenuTitle *title_arrange;
  FXMenuRadio *radio_det;
  FXMenuRadio *radio_sma;
  FXMenuRadio *radio_big;

  FXMenuPane *menu_show;
  FXMenuTitle *title_show;
  FXMenuCheck *check_fil;
  FXMenuCheck *check_dir;
  FXMenuCheck *check_img;

  FXMenuPane *menu_about;
  FXMenuTitle *title_about;
  FXMenuCommand *cmd_about;

  FXVerticalFrame *dialogframe;
  FXHorizontalFrame *filesframe;
  FXSplitter *splitter;
  FXVerticalFrame *buttonsframe;
  // progressbar
  fxmmProgressbar *progressbar;

  // file list classes
  FXDirList  	*dirlist;
  fxmmFileList	*filelist;
#ifdef HAVE_LIBFOX_1_7
  FXFileAssociations *associations;
#elif HAVE_LIBFOX_1_6
  FXFileDict *associations;
#endif
  FXString  currentdir;
  FXString  filename;

  FXString  dlg_cmd;
  FXString  dlg_label;
  FXString  dlg_ext;
  FXint	    dlg_form;

  FXString  fontspec;
  FXString  fontspec2;
  FXFont    *bodyfont;
  FXFont    *menufont;

  FXString  terminal;

  FXColor 	theme_fxmmbase;
  FXColor 	theme_fxmmborder;
  FXColor 	theme_fxmmfore;
  FXColor 	theme_fxmmselfore;
  FXColor 	theme_fxmmmenufore;
  FXColor 	theme_fxmmtipfore;
  FXColor 	theme_fxmmback;
  FXColor 	theme_fxmmselback;
  FXColor 	theme_fxmmmenuback;
  FXColor 	theme_fxmmtipback;
  FXColor 	theme_fxmmhilite;
  FXColor 	theme_fxmmshadow;

  FXString	language;
  FXString	file_n;
  FXString	file_t;
  FXString	file_s;
  FXString	file_m;
  FXString	file_u;
  FXString	file_g;
  FXString	file_a;
  FXString	file_l;

  FXString    menu_op;
  FXString    menu_ow;
  FXString    menu_re;
  FXString    menu_co;
  FXString    menu_cu;
  FXString    menu_de;
  FXString    menu_rf;
  FXString    menu_te;
  FXString    menu_he;
  FXString    menu_pa;

  FXString	menu_cm;
  FXString	menu_ex;
  FXString	menu_ec;

public:
  enum{
   	ID_QUIT=FXMainWindow::ID_LAST,
	ID_CLIPBOARD_CUT,
	ID_CLIPBOARD_COPY,
	ID_CLIPBOARD_PASTE,
   	ID_MAINWINDOW,
	ID_COMPRESS_TAR,
	ID_COMPRESS_GZ,
	ID_COMPRESS_BZ2,
	ID_COMPRESS_XZ,
	ID_COMPRESS_LZO,
	ID_COMPRESS_ZIP,
	ID_COMPRESS_7ZIP,
	ID_EXTRACT,
	ID_FORCEEXTRACT,
	ID_FILELIST,
	ID_DIRLIST,
	ID_TERMINAL,
	ID_COMMAND,
	ID_OPEN,
	ID_OPENWITH,
	ID_FILERENAME,
	ID_FILEDELETE,
	ID_SCAN,
	ID_MAP,
	ID_UNMAP,
	ID_ABOUT,
   	ID_LAST
    };


public:
    // Message handlers
    long onCmdQuit(FXObject*,FXSelector,void*);
	// compression
    long onCmdCompressTAR(FXObject*,FXSelector,void*);
    long onCmdCompressXZ(FXObject*,FXSelector,void*);
    long onCmdCompressLZO(FXObject*,FXSelector,void*);
    long onCmdCompressGZ(FXObject*,FXSelector,void*);
    long onCmdCompressBZ2(FXObject*,FXSelector,void*);
    long onCmdCompressZIP(FXObject*,FXSelector,void*);
    long onCmdCompress7ZIP(FXObject*,FXSelector,void*);
    long onCmdExtract(FXObject*,FXSelector,void*);
    long onCmdForceExtract(FXObject*,FXSelector,void*);
    long onUpdSelectedCompressTar(FXObject*,FXSelector,void*);
    long onUpdSelectedCompressZip(FXObject*,FXSelector,void*);
    long onUpdSelectedCompressAll(FXObject*,FXSelector,void*);
    long onUpdSelectedExtract(FXObject*,FXSelector,void*);
	// commands
    long onCmdTerminal(FXObject*,FXSelector,void*);
    long onCmdCommand(FXObject*,FXSelector,void*);
    long onCmdOpen(FXObject*,FXSelector,void*);
    long onCmdOpenWith(FXObject*,FXSelector,void*);
    long onCmdFilelist(FXObject*,FXSelector,void* ptr);
    long onCmdFileRename(FXObject*,FXSelector,void*);
    long onCmdFileDelete(FXObject*,FXSelector,void*);
    long onCmdDirlist(FXObject*,FXSelector,void* ptr);
    long onCmdAbout(FXObject*,FXSelector,void*);
    long onUpdFileSelected(FXObject* sender,FXSelector,void*);
    long onUpdTitle(FXObject* sender,FXSelector,void*);
    long onFileListPopup(FXObject*,FXSelector,void* ptr);
    long onDirListPopup(FXObject*,FXSelector,void* ptr);
	// clipboard
    long onClipboardLost(FXObject* sender,FXSelector sel,void* ptr);
    long onClipboardGained(FXObject* sender,FXSelector sel,void* ptr);
    long onClipboardRequest(FXObject* sender,FXSelector sel,void* ptr);
    long onCmdCopyCut(FXObject*,FXSelector sel,void*);
    long onCmdPaste(FXObject*,FXSelector sel,void*);
    long onUpdPaste(FXObject* o,FXSelector sel,void*);

    long onCmdScanHost(FXObject*,FXSelector,void*);
    long onCmdMapHost(FXObject*,FXSelector,void*);
    long onCmdUnmapHost(FXObject*,FXSelector,void*);
public:
    // Construct dialog
    ArchiveDialog(FXApp *);
    virtual void create();
    // Destroy
    virtual ~ArchiveDialog();

    FXbool readConfig();
    FXbool extractArchive(FXString& filename);
    FXbool executeCompressCommand(fxmmFileList* panel, const FXString& dlg_cmd, const FXString& dlg_ext, const FXString& dlg_label, FXint dlg_form);
    FXbool executeMapping(const FXString& map_cmd, const FXString& map_label);
    FXbool compareDevice(const FXString& devname);
    FXint getNumFilenames(fxmmFileList* filelist) const;
    void CompressTAR(fxmmFileList* panel);
    void CompressXZ(fxmmFileList* panel);
    void CompressLZO(fxmmFileList* panel);
    void CompressGZ(fxmmFileList* panel);
    void CompressBZ2(fxmmFileList* panel);
    void CompressZIP(fxmmFileList* panel);
    void Compress7ZIP(fxmmFileList* panel);
    void setDirectory(const FXString& dirname);
    void updateMappedDevices(FXFileList *devlist, FXbool askdialog);
    void updateMappedDevices1(FXFileList *devlist, FXbool askdialog);
    void updateMappedDevices2(FXFileList *devlist, FXbool askdialog);
    void updateMappedDevices3(FXFileList *devlist, FXString& user, FXString& temp);

  };

#endif
