/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 6.5                   *
*********************************************************************************
* Id: fxmmExtractDialog.cpp,                      2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/

#include <xincs.h>
#include <fx.h>
#include "config.h"
#include "icons.h"
#include "fxmmExtractDialog.h"

// Map
FXDEFMAP(fxmmExtractDialog) fxmmExtractDialogMap[]={
  FXMAPFUNC(SEL_COMMAND,  fxmmExtractDialog::ID_CANCEL,     fxmmExtractDialog::onCmdCancel),
  FXMAPFUNC(SEL_COMMAND,  fxmmExtractDialog::ID_ACCEPT,     fxmmExtractDialog::onCmdAccept),
  };

// Object implementation
FXIMPLEMENT(fxmmExtractDialog,FXDialogBox,fxmmExtractDialogMap,ARRAYNUMBER(fxmmExtractDialogMap))


// Create dialog
fxmmExtractDialog::fxmmExtractDialog(FXWindow *own)
  :FXDialogBox(own,"Extract Archive",DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,0,0,0,0, 4,4,4,4, 4,4){
  cancelicon=new FXGIFIcon(getApp(),m_cancel);
  accepticon=new FXGIFIcon(getApp(),m_accept);

  dialogframe=new FXVerticalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_THICK|FRAME_SUNKEN, 0,0,0,0, 0,0,0,0,0,0);
  new FXLabel(dialogframe,tr("press  [Accept]  to extract"),NULL,ICON_BEFORE_TEXT|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X,0,0,0,0, 3,3,3,3);

  // content
  inputframe=new FXHorizontalFrame(dialogframe,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_CENTER_Y,0,0,0,0, 0,0,0,0, 10,10);

  // buttons
  FXGroupBox *group1=new FXGroupBox(inputframe,"Accept Command",GROUPBOX_TITLE_CENTER|FRAME_RIDGE);
  new FXButton(group1,tr("&ACCEPT"),accepticon,this,ID_ACCEPT,BUTTON_NORMAL,0,0,0,0,10,10);
  new FXButton(group1,tr("&CANCEL"),cancelicon,this,ID_CANCEL,BUTTON_DEFAULT|BUTTON_NORMAL,0,0,0,0,10,10);

  // controls
  FXGroupBox *group2=new FXGroupBox(inputframe,"Set Password",GROUPBOX_TITLE_CENTER|FRAME_RIDGE);
  pw_input=new FXTextField(group2,14,NULL,0,TEXTFIELD_PASSWD|TEXTFIELD_READONLY|JUSTIFY_LEFT,0,0,0,0, 3,3,3,3);
  pw_button=new FXToggleButton(group2,"NO","YES",cancelicon,accepticon,pw_input,FXTextField::ID_TOGGLE_EDITABLE,BUTTON_TOOLBAR|ICON_BEFORE_TEXT|FRAME_RAISED|FRAME_THICK|LAYOUT_FILL_X);

  // copyright
  new FXSeparator(dialogframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame *copyright=new FXHorizontalFrame(dialogframe,LAYOUT_BOTTOM|LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  FXLabel *label = new FXLabel(copyright,"FXMovieManager - Archive Extraction",NULL,LAYOUT_FILL_X|LAYOUT_CENTER_Y|JUSTIFY_LEFT,0,0,0,0,15);
  // set the same look of separators
  label->disable();

  }


// Destroy
fxmmExtractDialog::~fxmmExtractDialog(){
  delete cancelicon;
  delete accepticon;
  }

// We have to do this so as to force the initial text to be seleced
FXuint fxmmExtractDialog::execute(FXuint placement){
  create();
  pw_input->setFocus();
  pw_input->selectAll();
  show(placement);
  return getApp()->runModalFor(this);
  }

// get the search option
long fxmmExtractDialog::onCmdAccept(FXObject* sender,FXSelector sel,void* ptr){
  pw_input->setFocus();
  pw_input->selectAll();
  if(!pw_input->isEditable())
    pw_input->setText("");

  FXDialogBox::onCmdAccept(sender,sel,ptr);
  return 1;
  }

// get the search option
long fxmmExtractDialog::onCmdCancel(FXObject* sender,FXSelector sel,void* ptr){
  FXDialogBox::onCmdCancel(sender,sel,ptr);
  return 1;
  }

