/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 6.5                   *
*********************************************************************************
* Id: fxmmprogressbar.cpp,                        2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/

#include <xincs.h>
#include <fx.h>
#include "config.h"
#include "fxmmProgressbar.h"


// Map
FXDEFMAP(fxmmProgressbar) fxmmProgressbarMap[]={
	FXMAPFUNC(SEL_PAINT,0,fxmmProgressbar::onPaint),
};

FXIMPLEMENT(fxmmProgressbar,FXFrame,fxmmProgressbarMap,ARRAYNUMBER(fxmmProgressbarMap))

//  Make the object 
fxmmProgressbar::fxmmProgressbar(FXComposite* p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h,
				FXint pl,FXint pr,FXint pt,FXint pb):FXFrame(p,opts, x,y,w,h, pl,pr,pt,pb){

  target=tgt;
  message=sel;
  progress=0;
  total=100;
  font=getApp()->getNormalFont();

  barBackColor=getApp()->getBackColor();
  barColor=getApp()->getSelbackColor();
  textColor=getApp()->getForeColor();
  textAltColor=getApp()->getBackColor();
}


// Destroy
fxmmProgressbar::~fxmmProgressbar(){
	font=(FXFont*)-1L;
}


FXint fxmmProgressbar::getDefaultWidth(){
	register FXint w=1,t;
	w=barsize;
	t=font->getTextWidth("100%",4);
	if(w<t) w=t;
	return w+padleft+padright+(border<<1);
}


FXint fxmmProgressbar::getDefaultHeight(){
	register FXint h=1,t;
	return h+padtop+padbottom+(border<<1);
}


void fxmmProgressbar::create(){
	FXFrame::create();
	font->create();
}


void fxmmProgressbar::detach(){
	FXFrame::detach();
	font->detach();
}


// Draw only the interior, i.e. the part that changes
void fxmmProgressbar::drawInterior(FXDCWindow& dc){
    register FXdouble fraction=(total>0)?((FXdouble)progress/(FXdouble)total):1.0;
    register FXint percent,barlength,barwidth,barfilled,tx,ty,tw,th,dx,dy,ds,n;
    FXchar numtext[10];
//  Calculate percentage complete
    percent=(FXuint)(100.0*fraction);
//  If total is 0, it's 100%
    barfilled=(FXuint)(23040.0*fraction);
//  Dial size and location
    tw=width-(border<<1)-padleft-padright;
    th=height-(border<<1)-padtop-padbottom;
    ds=FXMIN(tw,th)-1;
    dx=border+padleft+(tw-ds)/2;
    dy=border+padtop+(th-ds)/2;

//  Draw unfilled 
    if(barfilled!=23040){
      dc.setForeground(barBackColor);
      dc.fillArc(dx,dy,ds,ds,5760,23040-barfilled);
    }

//  Draw filled
    if(barfilled!=0){
//    Gradient method
      for(int i=ds; i>0; i-=4){
#ifdef HAVE_LIBFOX_1_7
        dc.setForeground(makeBlendColor(barBackColor,barColor,(100*i+ds/2)/ds));
#elif HAVE_LIBFOX_1_6
        dc.setForeground(barColor);
#endif
        dc.fillArc(dx+(ds-i)/2,dy+(ds-i)/2,i,i,5760,-barfilled);
      }
    }

//  Draw outside circle
    dc.setForeground(borderColor);
    dc.drawArc(dx+1,dy,ds,ds,90*64,45*64);
    dc.drawArc(dx,dy+1,ds,ds,135*64,45*64);
    dc.setForeground(baseColor);
    dc.drawArc(dx-1,dy,ds,ds,270*64,45*64);
    dc.drawArc(dx,dy-1,ds,ds,315*64,45*64);

    dc.setForeground(shadowColor);
    dc.drawArc(dx,dy,ds,ds,45*64,180*64);
    dc.setForeground(hiliteColor);
    dc.drawArc(dx,dy,ds,ds,225*64,180*64);

//	Draw text
    if(options&FXMMPROGRESSBAR_TEXT){
      tw=font->getTextWidth("100%",4);
      if(tw>(10*ds)/16) return;                  
//	Text wide
      th=font->getFontHeight();
      if(th>ds/2) return;                        
//	Text tall
      n=snprintf(numtext,sizeof(numtext),"%d%%",percent);
      tw=font->getTextWidth(numtext,n);
      th=font->getFontHeight();
      tx=dx+ds/2-tw/2;
      ty=dy+ds*0.75+font->getFontAscent();
      dc.setFont(font);
      dc.setForeground(textColor);
      dc.drawText(tx,ty,numtext,n);
    }
}


// Set amount of progress made
void fxmmProgressbar::setProgress(FXuint value){
  if(value>total) value=total;
  if(value!=progress){
    progress=value;
    if(xid){
      FXDCWindow dc(this);
      drawInterior(dc);
      }
    getApp()->flush();
    }
}


// Set total amount to completion
void fxmmProgressbar::setTotal(FXuint value){
  if(value!=total){
    total=value;
    if(xid){
      FXDCWindow dc(this);
      drawInterior(dc);
      }
    getApp()->flush();
    }
  }


// Change bar color
void fxmmProgressbar::setBarColor(FXColor clr){
  if(barColor!=clr){
    barColor=clr;
    update(border,border,width-(border<<1),height-(border<<1));
    }
  }


// Change bar background color
void fxmmProgressbar::setBarBackColor(FXColor clr){
  if(barBackColor!=clr){
    barBackColor=clr;
    update(border,border,width-(border<<1),height-(border<<1));
    }
  }


// Change text foreground color
void fxmmProgressbar::setTextColor(FXColor clr){
  if(textColor!=clr){
    textColor=clr;
    update();
    }
  }


// Change alternate text color
void fxmmProgressbar::setTextAltColor(FXColor clr){
  if(textAltColor!=clr){
    textAltColor=clr;
    update();
    }
  }


// Change the font
void fxmmProgressbar::setFont(FXFont *fnt){
  if(!fnt){ fxerror("%s::setFont: NULL font specified.\n",getClassName()); }
  if(font!=fnt){
    font=fnt;
    recalc();
    update();
    }
  }


// Draw the progress bar
long fxmmProgressbar::onPaint(FXObject*, FXSelector, void *ptr){
  FXDCWindow dc(this,(FXEvent*)ptr);

  // Erase to base color
  dc.setForeground(baseColor);
  dc.fillRectangle(0,0,width,height);

  // Draw borders
  drawFrame(dc,padleft,padtop,width-padleft-padright,height-padtop-padbottom);

  // Draw interior
  drawInterior(dc);
  return 1;

}

