/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 6.5                   *
*********************************************************************************
* Id: fxscanvirus.cpp,                            2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/
#include <fx.h>
#include <signal.h>

#include "icons.h"
#include "fxscanvirus.h"

#ifdef HAVE_CLAMAV_H
#include <clamav.h>
#endif

#ifdef HAVE_LIBFOX_1_6
#include "FXPNGIcon.h"
#endif

#ifdef HAVE_LIBFOX_1_7
 #define VALUE_TO_STRING FXString::value
#elif HAVE_LIBFOX_1_6
 #define VALUE_TO_STRING FXStringVal
#endif

// Message Map for the Scribble Window class
FXDEFMAP(ScanVirusDialog) ScanVirusDialogMap[]={

  //________Message_Type_____________________ID____________Message_Handler_______
  FXMAPFUNC(SEL_UPDATE,            ScanVirusDialog::ID_MAINWIN, ScanVirusDialog::onUpdTitleDir),
  FXMAPFUNC(SEL_COMMAND,		   ScanVirusDialog::ID_SCAN,    ScanVirusDialog::onCmdScan),
  FXMAPFUNC(SEL_COMMAND,		   ScanVirusDialog::ID_QUIT,    ScanVirusDialog::onCmdQuit),

  FXMAPFUNC(SEL_DOUBLECLICKED, 	   ScanVirusDialog::ID_FILELIST,ScanVirusDialog::onCmdFilelist),
  FXMAPFUNC(SEL_COMMAND,		   ScanVirusDialog::ID_DIRLIST,	ScanVirusDialog::onCmdDirlist),

  FXMAPFUNC(SEL_COMMAND,		   ScanVirusDialog::ID_INFO,    ScanVirusDialog::onCmdInfo),
  FXMAPFUNC(SEL_COMMAND,		   ScanVirusDialog::ID_ABOUT,   ScanVirusDialog::onCmdAbout),
  };


// Macro for the ScanVirusApp class hierarchy implementation
FXIMPLEMENT(ScanVirusDialog,FXMainWindow,ScanVirusDialogMap,ARRAYNUMBER(ScanVirusDialogMap))

// Create properties dialog
ScanVirusDialog::ScanVirusDialog(FXApp *a)
  :FXMainWindow(a,"FX ScanVirus Utility",NULL,NULL,DECOR_ALL,0,0,680,600){

  // set icon on the main window
  logoicon=new FXPNGIcon(getApp(),fxsv64);
  logominiicon=new FXPNGIcon(getApp(),fxsv16);
  setIcon(logoicon);
  setMiniIcon(logominiicon);

  setTarget(this);
  setSelector(ID_MAINWIN);
  // wheel icons
  uicon=new FXGIFIcon(getApp(),m_wash_up);
  ricon=new FXGIFIcon(getApp(),m_wash_right);
  dicon=new FXGIFIcon(getApp(),m_wash_down);
  licon=new FXGIFIcon(getApp(),m_wash_left);
  // mark icons
  cancelicon=new FXGIFIcon(getApp(),m_cancel);
  accepticon=new FXGIFIcon(getApp(),m_accept);
  infectedicon=new FXGIFIcon(getApp(),m_bug);
  scanicon=new FXGIFIcon(getApp(),m_bug_big);
  quiticon=new FXGIFIcon(getApp(),m_quit_big);
  // filelist header
  m_renamediricon=new FXGIFIcon(getApp(),m_renamedir);
  m_usricon=new FXGIFIcon(getApp(),m_usr);
  m_grpicon=new FXGIFIcon(getApp(),m_grp);
  m_prmicon=new FXGIFIcon(getApp(),m_prm);
  m_dimicon=new FXGIFIcon(getApp(),m_dim);
  m_daticon=new FXGIFIcon(getApp(),m_dat);
  m_diricon=new FXGIFIcon(getApp(),m_dir);
  m_consoleicon=new FXGIFIcon(getApp(),m_console);

  if(!readConfig()){
	  printf("Configuration not loaded!");
  }

  // menubar
  menubar = new FXMenuBar(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);

  dialogframe=new FXVerticalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_THICK|FRAME_SUNKEN, 0,0,0,0, 0,0,0,0,0,0);
  lineframe=new FXHorizontalFrame(dialogframe,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|FRAME_THICK,0,0,0,0, 0,0,0,0);
  label_cu=new FXLabel(lineframe,"Current File Scanned:");
  linelist=new FXTextField(lineframe,100,NULL,0,FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X,0,0,0,0);

  splitterv=new FXSplitter(dialogframe,LAYOUT_SIDE_TOP|FRAME_RAISED|LAYOUT_FILL_X|LAYOUT_FILL_Y|SPLITTER_TRACKING|SPLITTER_VERTICAL);
  viewframe=new FXHorizontalFrame(splitterv,LAYOUT_SIDE_BOTTOM|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0);
  legendframe=new FXVerticalFrame(viewframe,LAYOUT_FILL_Y, 0,0,0,0, 0,0,0,0,0,0);
  new FXLabel (legendframe," ");
  label_su=new FXLabel (legendframe," Summary:");
  new FXLabel (legendframe," ");
  label_cl=new FXLabel(legendframe,"Clean", accepticon);
  label_in=new FXLabel(legendframe,"Infected", infectedicon);
  label_re=new FXLabel(legendframe,"Removed", cancelicon);
  new FXLabel (legendframe," ");
  viewlist=new FXList(viewframe,NULL,0,FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0);

  splitterh=new FXSplitter(splitterv,LAYOUT_SIDE_TOP|FRAME_RAISED|LAYOUT_FILL_Y|SPLITTER_TRACKING|SPLITTER_HORIZONTAL|SPLITTER_REVERSED);
  dirlist=new FXDirList(splitterh,this,ID_DIRLIST,LAYOUT_FILL_X|LAYOUT_FILL_Y|TREELIST_SHOWS_LINES|TREELIST_SHOWS_BOXES|TREELIST_BROWSESELECT|DIRLIST_NO_OWN_ASSOC,0,0,0,0);
  filelist=new FXFileList(splitterh,this,ID_FILELIST,LAYOUT_FILL_X|LAYOUT_FILL_Y|ICONLIST_MINI_ICONS|ICONLIST_AUTOSIZE|FILELIST_NO_OWN_ASSOC,0,0,500,0);
  filelist->setDirectory(currentdir);
  dirlist->setDirectory(currentdir);

  // Arrange menu
  menu_arrange=new FXMenuPane(this);
  title_arrange=new FXMenuTitle(menubar,"&Arrange",NULL,menu_arrange);
  radio_det=new FXMenuRadio(menu_arrange,"Detailed &List\t\tView as detailed list.",filelist,FXFileList::ID_SHOW_DETAILS);
  radio_sma=new FXMenuRadio(menu_arrange,"&Mini icons\t\tView as small icons.",filelist,FXFileList::ID_SHOW_MINI_ICONS);
  radio_big=new FXMenuRadio(menu_arrange,"&Big icons\t\tView as big icons.",filelist,FXFileList::ID_SHOW_BIG_ICONS);

  // Show/Hide menu
  menu_show=new FXMenuPane(this);
  title_show=new FXMenuTitle(menubar,"&Hide/Show",NULL,menu_show);
  check_fil=new FXMenuCheck(menu_show,"Hidden &Directories\t\tShow hidden directories.",dirlist,FXDirList::ID_TOGGLE_HIDDEN);
  check_dir=new FXMenuCheck(menu_show,"Hidden &Files\t\tShow hidden files and directories.",filelist,FXFileList::ID_TOGGLE_HIDDEN);

  // About menu
  menu_about=new FXMenuPane(this);
  title_about=new FXMenuTitle(menubar,"&Information",NULL,menu_about,LAYOUT_RIGHT);
  cmd_about=new FXMenuCommand(menu_about,"&About\t\tAbout FXScanVirus",logominiicon,this,ID_ABOUT);
  cmd_about=new FXMenuCommand(menu_about,"&Engine\t\tlibClamAv engine",infectedicon,this,ID_INFO);

  new FXHorizontalSeparator(dialogframe,SEPARATOR_GROOVE|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);

  // Progress bar
  progressframe=new FXVerticalFrame(dialogframe,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X, 0,0,0,0, 0,0,0,0,0,0);
  totalprogressbar=new FXProgressBar(progressframe,NULL,0,PROGRESSBAR_HORIZONTAL|PROGRESSBAR_PERCENTAGE|PROGRESSBAR_NORMAL|LAYOUT_FILL_X);

  new FXHorizontalSeparator(dialogframe,SEPARATOR_GROOVE|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);

  // buttons
  buttonsframe=new FXHorizontalFrame(dialogframe,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0, 0,0,0,0);
  button_sc=new FXButton(buttonsframe,tr(" &SCAN "),scanicon,this,ID_SCAN,BUTTON_DEFAULT|BUTTON_NORMAL|LAYOUT_CENTER_X,0,0,0,0,0,0,0,0);

  wheelframe=new FXHorizontalFrame(buttonsframe,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0, 0,0,0,0);
  label_wheel1=new FXLabel(wheelframe,"", uicon);
  label_wheel2=new FXLabel(wheelframe,"", ricon);
  label_wheel3=new FXLabel(wheelframe,"", dicon);
  label_wheel4=new FXLabel(wheelframe,"", licon);

  button_qu=new FXButton(buttonsframe,tr(" &QUIT "),quiticon,this,ID_QUIT,BUTTON_DEFAULT|BUTTON_NORMAL|LAYOUT_CENTER_X,0,0,0,0,0,0,0,0);


  new FXSeparator(dialogframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame *infoframe=new FXHorizontalFrame(dialogframe,LAYOUT_BOTTOM|LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  infolabel_name = new FXLabel(infoframe,"FXScanVirus ",NULL,LAYOUT_FILL_X|LAYOUT_CENTER_X|JUSTIFY_LEFT,0,0,0,0,15);
  infolabel_msg = new FXLabel(infoframe,"",NULL,LAYOUT_FILL_X|LAYOUT_CENTER_X|JUSTIFY_LEFT,0,0,0,0,15);

  // set the same look of separators
  infolabel_name->disable();
  // set clamav to not-initialized
  initclamav=false;
  flushclamav=false;
}

// Destroy
ScanVirusDialog::~ScanVirusDialog(){
  delete accepticon;
  delete cancelicon;
  delete infectedicon;
  delete quiticon;
  delete scanicon;
  delete uicon;
  delete ricon;
  delete dicon;
  delete licon;
  // filelist header
  delete m_renamediricon;
  delete m_usricon;
  delete m_grpicon;
  delete m_prmicon;
  delete m_dimicon;
  delete m_daticon;
  delete m_diricon;
  delete m_consoleicon;
  }

// Update progressbar with current amount of files scanned
inline void ScanVirusDialog::updTotalProgress(FXint progress){
  totalprogressbar->setProgress(0);
  totalprogress=totalprogress+progress;
  totalprogressbar->setTotal(totalprogress);
  printf("total progress:%d\n",totalprogress);
}


// Update title with current amount of files scanned
inline void ScanVirusDialog::updTitleProgress(){
  FXint pval = 100 * totalprogressbar->getProgress()/totalprogressbar->getTotal();
  FXString title="FXScanVirus: " + VALUE_TO_STRING(pval) + " %";
  handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_SETSTRINGVALUE),(void*)&title);
}


void ScanVirusDialog::updIconsProgress(){
  FXIcon *wicon = NULL;
  wicon=label_wheel1->getIcon();

  if(wicon==uicon){
	label_wheel1->setIcon(licon);	
	label_wheel2->setIcon(dicon);
	label_wheel3->setIcon(ricon);
	label_wheel4->setIcon(uicon);	
  }else if(wicon==licon){
	label_wheel1->setIcon(dicon);
	label_wheel2->setIcon(ricon);
	label_wheel3->setIcon(uicon);
	label_wheel4->setIcon(licon);	
  }else if(wicon==dicon){
	label_wheel1->setIcon(ricon);
	label_wheel2->setIcon(uicon);
	label_wheel3->setIcon(licon);	
	label_wheel4->setIcon(dicon);
  }else if(wicon==ricon){
	label_wheel1->setIcon(uicon);
	label_wheel2->setIcon(licon);
	label_wheel3->setIcon(dicon);
	label_wheel4->setIcon(ricon);	
  }
  label_wheel1->repaint();
  label_wheel2->repaint();
  label_wheel3->repaint();
  label_wheel4->repaint();
}


inline void ScanVirusDialog::recurUpdProgress(const FXString& dirname){

    FXSplitter *splittern=new FXSplitter(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|SPLITTER_TRACKING|SPLITTER_VERTICAL|SPLITTER_REVERSED);
	FXFileList *panel=new FXFileList(splittern,this,0,LAYOUT_FILL_X|ICONLIST_MINI_ICONS|ICONLIST_AUTOSIZE|FILELIST_NO_OWN_ASSOC);
  	FXString path=FXPath::absolute(dirname);
  	panel->setDirectory(path);

	FXString nextdir;
	FXint progress = 0;

    // start from 0 means go upper level
    for(FXint i=1; i<panel->getNumItems(); i++){
		if(panel->isItemDirectory(i)){
   			nextdir=panel->getItemPathname(i);
			recurUpdProgress(nextdir); // recursion
		}
		else
		if(panel->isItemFile(i)){
			progress++;
		}	
	}

	// increment maximum value of total progress bar 
	updTotalProgress(progress);

}


inline void ScanVirusDialog::recurUpdFilelist(int ret, const char *virname, struct cl_engine *engine, const FXString& dirname){

    FXSplitter *splittern=new FXSplitter(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y|SPLITTER_TRACKING|SPLITTER_VERTICAL|SPLITTER_REVERSED);
	FXFileList *panel=new FXFileList(splittern,this,0,LAYOUT_FILL_X|ICONLIST_MINI_ICONS|ICONLIST_AUTOSIZE|FILELIST_NO_OWN_ASSOC);
  	FXString path=FXPath::absolute(dirname);
  	panel->setDirectory(path);
	//printf("path:%s\n",path.text());
	FXString nextdir, filename, filetoscan;
	//printf("tot items: %d\n",panel->getNumItems());
    // start from 0 means go upper level
    for(FXint i=1; i<panel->getNumItems(); i++){
		if(panel->isItemDirectory(i)){
   			nextdir=panel->getItemPathname(i);
			printf("nextdir:%s\n",nextdir.text());
			recurUpdFilelist(ret, virname, engine, nextdir); // recursion
		}
		else
		if(panel->isItemFile(i)){
			filename=panel->getItemFilename(i);
			filetoscan=FXPath::absolute(panel->getDirectory(),filename);
			printf("scan:%s\n",filetoscan.text());
			if(flushclamav==false)
				scanFileName(ret, virname, engine, filetoscan, i);
		}
	}

	return;
}


int ScanVirusDialog::execScanVirus(FXFileList* panel, FXbool initclam){

    viewlist->clearItems();
	s_infolabel.clear();

#ifdef HAVE_LIBCLAMAV
    int ret;
    unsigned int sigs = 0;
    flushclamav=false;
    const char *virname;
    struct cl_engine *engine;

	getApp()->beginWaitCursor();

	// initialize clamav
	if (initclam==false){
		initclam=true;
    	if((ret = cl_init(CL_INIT_DEFAULT)) != CL_SUCCESS) {
      		FXMessageBox::error(this,MBOX_OK,"ERROR","Can't initialize libclamav: %s\n", cl_strerror(ret));
	  		return 1;
		}else{
			s_infolabel.append("libclamav initialized - ");
		}
    }
	// new engine
	if(!(engine = cl_engine_new())) {
		FXMessageBox::error(this,MBOX_OK,"ERROR","Can't create new engine");
		return 1;
	}else{
		s_infolabel.append("new engine created - ");
	}
	// load all available databases from default directory
	if((ret = cl_load(cl_retdbdir(), engine, &sigs, CL_DB_STDOPT)) != CL_SUCCESS) {
		FXMessageBox::error(this,MBOX_OK,"Clamav_load: %s\n", cl_strerror(ret));
		cl_engine_free(engine);
		return 1;
	}else{
		FXString s_sign;
		int sign = (int)sigs;
		s_sign = VALUE_TO_STRING(sign);

		s_infolabel.append("loaded ");
		s_infolabel.append(s_sign.text());
		s_infolabel.append(" signatures - ");
    }
    printf("Loaded %u signatures.\n", sigs);
	// build engine
	if((ret = cl_engine_compile(engine)) != CL_SUCCESS) {
		FXMessageBox::error(this,MBOX_OK,"ERROR","Database initialization error: %s\n", cl_strerror(ret));
		cl_engine_free(engine);
		return 1;
	}else{
		s_infolabel.append("database initialized - ");
	}

	infolabel_msg->setText(s_infolabel);
	infolabel_msg->update();

	getApp()->endWaitCursor();

    FXString dirname, filename, filetoscan;

    totalprogressbar->setBarColor(FXRGB(50,250,50));

    FXint progress=0;
	totalprogress=0;

	// Deselect the '..' directory
	if (panel->isItemSelected(0)){
		panel->deselectItem(0);
	}

	getApp()->beginWaitCursor();

	// recursively increment the maximum value of the progress bar
    for(FXint i=1; i<panel->getNumItems(); i++){
        // on the main directory count only selected files
    	if(panel->isItemSelected(i)){
			if(panel->isItemDirectory(i)){
       			dirname=panel->getItemPathname(i);
				recurUpdProgress(dirname);
			}
			else
			if(panel->isItemFile(i)){
				progress++;
			}	
		}
	}
	updTotalProgress(progress);

	// recursively update list of files
    for(FXint i=1; i<panel->getNumItems(); i++){
        // on the main directory scan only selected files
    	if(panel->isItemSelected(i)){
			if(panel->isItemDirectory(i)){
       			dirname=panel->getItemPathname(i);
				recurUpdFilelist(ret, virname, engine, dirname);
			}
			else
			if(panel->isItemFile(i)){
				filename=panel->getItemFilename(i);
				filetoscan=FXPath::absolute(panel->getDirectory(),filename);
				printf("scan: %s\n",filetoscan.text());
				if(flushclamav==false)
					scanFileName(ret, virname, engine, filetoscan, i);
			}
		}	
	}

	getApp()->endWaitCursor();
	totalprogressbar->setProgress(totalprogress);

    FXMessageBox::information(this,MBOX_OK,"Virus Scanning Summary","No know virus detected");
    // eventually free the engine buffer
    cl_engine_free(engine);
#endif
    return 1;
  }


void ScanVirusDialog::scanFileName(int ret, const char *virname, struct cl_engine *engine, FXString& filetoscan, int i) {
#ifdef HAVE_LIBCLAMAV
    long double mb;
    unsigned long int size = 0;

	updIconsProgress();
	// show filename processed
	linelist->setText(filetoscan.text());
	linelist->repaint();

     // scan filename
     if((ret = cl_scanfile(filetoscan.text(), &virname, &size, engine, CL_SCAN_STDOPT)) == CL_VIRUS) {
    	totalprogressbar->setBarColor(FXRGB(250,50,50));
   	    totalprogressbar->increment(1);
		viewlist->prependItem(filetoscan.text(), infectedicon);
		viewlist->repaint();
        FXuint answer1=FXMessageBox::warning(this,MBOX_YES_NO,"Warning!","Virus detected: %s\nContinue with deleting dialog?", virname);
        // trying to delete the infected file
        if(answer1==MBOX_CLICKED_YES){
           FXuint answer2=FXMessageBox::warning(this,MBOX_YES_NO,"Deleting Movie!","Do YOU WANT TO DELETE this file? %s\n",filetoscan.text());
           if(answer2==MBOX_CLICKED_YES){
              FXTRACE((100,"filetoremove=%s\n",filetoscan.text()));
              if(!FXFile::remove(filetoscan)){
                if(MBOX_CLICKED_NO==FXMessageBox::error(this,MBOX_YES_NO,"Error Deleting Movie","Unable to delete movie: %s\nContinue with operation?",filetoscan.text())){
                   return;
                }
              }
			viewlist->prependItem(filetoscan.text(), cancelicon);
			viewlist->repaint();
            }
          }
        } else if(ret == CL_CLEAN) {
   	        totalprogressbar->increment(1);
            updTitleProgress();
			viewlist->prependItem(filetoscan.text(), accepticon);
			viewlist->repaint();
        } else {
          FXuint answer=FXMessageBox::error(this,MBOX_OK_CANCEL,"ERROR","Error: %s\n", cl_strerror(ret));
          if(answer==MBOX_CLICKED_CANCEL)
            flushclamav=true;
          return;
        }
     // calculate size of scanned data
     mb = size * (CL_COUNT_PRECISION / 1024) / 1024.0;
     printf("size: %2.2Lf MB\n", mb);
#endif
     return;
  }


// Scan at given positions 
long ScanVirusDialog::onCmdScan(FXObject*,FXSelector,void*){
  execScanVirus(filelist, initclamav);
  initclamav=true;
  return 1;
}

// Close dialog with quit
void ScanVirusDialog::quitApp(){
  // Write new window size and position back to registry
#ifdef HAVE_LIBFOX_1_7
  getApp()->reg().writeUIntEntry("FXScanVirus","width",(FXuint)getWidth());
  getApp()->reg().writeUIntEntry("FXScanVirus","height",(FXuint)getHeight());
#endif
#ifdef HAVE_LIBFOX_1_6
  getApp()->reg().writeUnsignedEntry("FXScanVirus","width",(FXuint)getWidth());
  getApp()->reg().writeUnsignedEntry("FXScanVirus","height",(FXuint)getHeight());
#endif 
  getApp()->reg().writeIntEntry("FXScanVirus","xpos",getX());
  getApp()->reg().writeIntEntry("FXScanVirus","ypos",getY());
  // set currentdir
  currentdir = dirlist->getDirectory();
  getApp()->reg().writeStringEntry("FXScanVirus","currentdir",currentdir.text());
  // Write registry settings
  getApp()->reg().write();
  // Quit
  getApp()->exit(0);
}


// Close dialog with quit
long ScanVirusDialog::onCmdQuit(FXObject*,FXSelector,void*){
  quitApp();
  return 1;
}


// Command from the tree list
long ScanVirusDialog::onCmdFilelist(FXObject*,FXSelector,void* ptr){
  FXint index=(FXint)(FXival)ptr;

  if(0<=index){
    if(filelist->isItemDirectory(index)){
      currentdir=filelist->getItemPathname(index);
      filelist->setDirectory(currentdir);
      dirlist->setDirectory(currentdir);
      }
    else if(filelist->isItemFile(index)){
      filename=filelist->getItemPathname(index);
      execScanVirus(filelist, initclamav);
      initclamav=true;
      }
    }
  return 1;
}


// Change the directory from the FXDirList
long ScanVirusDialog::onCmdDirlist(FXObject*,FXSelector,void* ptr){
  FXTreeItem *item=(FXTreeItem*)ptr;
  FXString path=dirlist->getItemPathname(item);
  filelist->setDirectory(path);
  return 1;
  }


// Update title with current directory viewed
long ScanVirusDialog::onUpdTitleDir(FXObject* sender,FXSelector,void*){
  FXString title="FXScanVirus: " + filelist->getDirectory();
  sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_SETSTRINGVALUE),(void*)&title);
  return 1;
  }


// Switch to given directory
void ScanVirusDialog::setDirectory(const FXString& dirname){
  FXString newpath=FXPath::absolute(dirname);
  filelist->setDirectory(newpath);
  dirlist->setDirectory(newpath);
  }


// create application
void ScanVirusDialog::create() {

    if(!fontspec.empty()){
      bodyfont=new FXFont(getApp(),fontspec);
      filelist->setFont(bodyfont);
      dirlist->setFont(bodyfont);
      linelist->setFont(bodyfont);
    }

    if(!fontspec2.empty()){
      menufont=new FXFont(getApp(),fontspec2);
      getApp()->setNormalFont(menufont);
      viewlist->setFont(menufont);
      label_cu->setFont(menufont);
      label_su->setFont(menufont);
      label_cl->setFont(menufont);
      label_in->setFont(menufont);
      label_re->setFont(menufont);
      button_sc->setFont(menufont);
      button_qu->setFont(menufont);
      totalprogressbar->setFont(menufont);
      title_arrange->setFont(menufont);
      radio_det->setFont(menufont);
      radio_sma->setFont(menufont);
      radio_big->setFont(menufont);
      title_show->setFont(menufont);
      check_fil->setFont(menufont);
      check_dir->setFont(menufont);
      title_about->setFont(menufont);
      cmd_about->setFont(menufont);
    }

	if(!currentdir.empty()){
      dirlist->setDirectory(currentdir);
      filelist->setDirectory(currentdir);
    }

    getApp()->setForeColor(theme_fxmmfore);
    getApp()->setBaseColor(theme_fxmmbase);
    getApp()->setBackColor(theme_fxmmback);
    getApp()->setBorderColor(theme_fxmmborder);
    getApp()->setSelMenuTextColor(theme_fxmmmenufore);
    getApp()->setSelMenuBackColor(theme_fxmmmenuback);
    getApp()->setSelforeColor(theme_fxmmselfore);
    getApp()->setSelbackColor(theme_fxmmselback);
    getApp()->setTipforeColor(theme_fxmmtipfore);
    getApp()->setTipbackColor(theme_fxmmtipback);
    getApp()->setHiliteColor(theme_fxmmhilite);
    getApp()->setShadowColor(theme_fxmmshadow);

    filelist->setHeaderIcon(0,m_renamediricon);
    filelist->setHeaderIcon(1,m_diricon);
    filelist->setHeaderIcon(2,m_dimicon);
    filelist->setHeaderIcon(3,m_daticon);
    filelist->setHeaderIcon(4,m_usricon);
    filelist->setHeaderIcon(5,m_grpicon);
    filelist->setHeaderIcon(6,m_prmicon);
    filelist->setHeaderIcon(7,m_consoleicon);

    filelist->setHeaderText(0,file_n);
    filelist->setHeaderText(1,file_t);
    filelist->setHeaderText(2,file_s);
    filelist->setHeaderText(3,file_m);
    filelist->setHeaderText(4,file_u);
    filelist->setHeaderText(5,file_g);
    filelist->setHeaderText(6,file_a);
    filelist->setHeaderText(7,file_l);

    // Make file associations object; 
    // shared between FXFileList and FXDirList
#ifdef HAVE_LIBFOX_1_7
    associations=new FXFileAssociations(getApp());
#elif HAVE_LIBFOX_1_6
    associations=new FXFileDict(getApp());
#endif

    filelist->setAssociations(associations);
    dirlist->setAssociations(associations);

    FXMainWindow::create();
    show(PLACEMENT_SCREEN);

    return;
}

FXbool ScanVirusDialog::readConfig() {
    // Read registry
	if(!getApp()->reg().read()){
		return false;
	}

    // Get size and position
#ifdef HAVE_LIBFOX_1_7
    FXuint width=getApp()->reg().readUIntEntry("FXScanVirus","width",680);
    FXuint height=getApp()->reg().readUIntEntry("FXScanVirus","height",600);
#endif
#ifdef HAVE_LIBFOX_1_6
    FXuint width=getApp()->reg().readUnsignedEntry("FXScanVirus","width",680);
    FXuint height=getApp()->reg().readUnsignedEntry("FXScanVirus","height",600);
#endif 

    FXint xpos=getApp()->reg().readIntEntry("FXScanVirus","xpos",40);
    FXint ypos=getApp()->reg().readIntEntry("FXScanVirus","ypos",5);

    // Reposition window
    position(xpos,ypos,width,height);

    currentdir=getApp()->reg().readStringEntry("FXScanVirus","currentdir");

  	if(! (theme_fxmmfore=getApp()->reg().readColorEntry("SETTINGS","fxmmforecolor"))) { theme_fxmmfore   = FXRGB(180,180,180);}
  	if(! (theme_fxmmback=getApp()->reg().readColorEntry("SETTINGS","fxmmbackcolor"))) { theme_fxmmback   = FXRGB( 20, 20, 20);}
  	if(! (theme_fxmmbase=getApp()->reg().readColorEntry("SETTINGS","fxmmbasecolor"))) { theme_fxmmbase   = FXRGB( 60, 60, 60);}
  	if(! (theme_fxmmborder=getApp()->reg().readColorEntry("SETTINGS","fxmmbordercolor"))) { theme_fxmmborder = FXRGB(  0,  0,  0);}
  	if(! (theme_fxmmmenufore=getApp()->reg().readColorEntry("SETTINGS","fxmmmenuforecolor"))) { theme_fxmmmenufore  = FXRGB(240,240,240);}
  	if(! (theme_fxmmmenuback=getApp()->reg().readColorEntry("SETTINGS","fxmmmenubackcolor"))) { theme_fxmmmenuback  = FXRGB( 10, 10, 10);}
  	if(! (theme_fxmmselfore=getApp()->reg().readColorEntry("SETTINGS","fxmmselforecolor"))) { theme_fxmmselfore   = FXRGB(  0,  0,  0);}
  	if(! (theme_fxmmselback=getApp()->reg().readColorEntry("SETTINGS","fxmmselbackcolor"))) { theme_fxmmselback   = FXRGB(140,140,140);}
  	if(! (theme_fxmmtipfore=getApp()->reg().readColorEntry("SETTINGS","fxmmtipforecolor"))) { theme_fxmmtipfore  = FXRGB(220,220,220);}
  	if(! (theme_fxmmtipback=getApp()->reg().readColorEntry("SETTINGS","fxmmtipbackcolor"))) { theme_fxmmtipback  = FXRGB( 20, 20, 20);}
  	if(! (theme_fxmmhilite=getApp()->reg().readColorEntry("SETTINGS","fxmmhilitecolor"))) { theme_fxmmhilite  = FXRGB(100,100,100);}
  	if(! (theme_fxmmshadow=getApp()->reg().readColorEntry("SETTINGS","fxmmshadowcolor"))) { theme_fxmmshadow  = FXRGB( 10, 10, 10);}


  language=getApp()->reg().readStringEntry("SETTINGS","language");
  if(language== "en" || language== "it" || language== "fr" || language== "de" || language== "es" || language== "ru" || language== "cn" || language== "jp" ){
  // Read language
    file_n=getApp()->reg().readStringEntry("LANG_MENU","file_n");
    file_t=getApp()->reg().readStringEntry("LANG_MENU","file_t");
    file_s=getApp()->reg().readStringEntry("LANG_MENU","file_s");
    file_m=getApp()->reg().readStringEntry("LANG_MENU","file_m");
    file_u=getApp()->reg().readStringEntry("LANG_MENU","file_u");
    file_g=getApp()->reg().readStringEntry("LANG_MENU","file_g");
    file_a=getApp()->reg().readStringEntry("LANG_MENU","file_a");
    file_l=getApp()->reg().readStringEntry("LANG_MENU","file_l");

  } else if(language=="cu"){
  // Read custom language
    file_n=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_n");
    file_t=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_t");
    file_s=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_s");
    file_m=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_m");
    file_u=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_u");
    file_g=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_g");
    file_a=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_a");
    file_l=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_l");
  }
  
    // Read font
    fontspec=getApp()->reg().readStringEntry("SETTINGS","bodyfont","");
    fontspec2=getApp()->reg().readStringEntry("SETTINGS","menufont","");

    // Read registry settings
	if(getApp()->reg().read()){
		return true;
	}
}


// libclamav Info box
long ScanVirusDialog::onCmdInfo(FXObject*,FXSelector,void*){
  FXString info;
  info.append("Version: ");
  info.append(cl_retver());
  info.append("\n");
  info.append("FLevel: ");
  info.append(VALUE_TO_STRING(cl_retflevel()));
  info.append("\n");
  FXMessageBox::information(this,MBOX_OK,"LIBCLAMAV engine",info.text());
  return 1;
  }


// About box
long ScanVirusDialog::onCmdAbout(FXObject*,FXSelector,void*){
  FXMessageBox about(this,"About FXScanVirus",
	"FXScanVirus is a simple virus scanner utility using libclamav,\n"
	"Copyright (C) 2010,2014 Luigi Ziviani (ziviani_luigi@yahoo.it).\n\n"
	"This program is free software; you can redistribute it\n"
	"and/or modify it under the terms of the GNU General Public\n"
	"License as published by the Free Software Foundation;\n"
	"either version 3 of the License, or(at your option)\n"
	"any later version.\n\n"
	"This program is distributed in the hope that it will be useful,\n"
	"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
	"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
	"See the GNU General Public License for more details.\n\n"
	"You should have received a copy of the GNU General Public License\n"
	"along with this program; if not, write to the \n"
	"Free Software Foundation, Inc.,\n"
	"59 Temple Place, Suite 330, Boston, MA  02111-1307  USA",
	logoicon,MBOX_OK|DECOR_TITLE|DECOR_BORDER);
	about.execute();
  return 1;
  }


// main
int main(int argc, char *argv[]) {
    // Make application
    FXApp application("Configuration","FXMM");
    // Open display
    application.init(argc,argv);
    // Make window: the new FXScanVirus(&application);
    ScanVirusDialog* fxscanvirus = new ScanVirusDialog(&application);
    // Handle interrupt to save stuff nicely
    application.addSignal(SIGINT,fxscanvirus,ScanVirusDialog::ID_QUIT);
    // Create it
    application.create();
    // Start in given directory
    if(argc==2) fxscanvirus->setDirectory(argv[1]);
    // Run
    return application.run();
}


// EOF
