/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 6.5                   *
*********************************************************************************
* Id: fxscanvirus.h,                              2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/
#ifndef FXSCANVIRUS_H
#define FXSCANVIRUS_H

#include "config.h"

class ScanVirusDialog : public FXMainWindow {
  FXDECLARE(ScanVirusDialog)

private:
  ScanVirusDialog(){};
  ScanVirusDialog(const ScanVirusDialog&){};

protected:
  FXIcon *logoicon;
  FXIcon *logominiicon;
  // wheel icons
  FXIcon *uicon;
  FXIcon *ricon;
  FXIcon *dicon;
  FXIcon *licon;
  // mark icons
  FXIcon *accepticon;
  FXIcon *cancelicon;
  FXIcon *infectedicon;
  FXIcon *scanicon;
  FXIcon *quiticon;
  // filelist headers
  FXIcon *m_renamediricon;
  FXIcon *m_usricon;
  FXIcon *m_grpicon;
  FXIcon *m_prmicon;
  FXIcon *m_dimicon;
  FXIcon *m_daticon;
  FXIcon *m_diricon;
  FXIcon *m_consoleicon;

  FXVerticalFrame   *dialogframe;
  FXHorizontalFrame *lineframe;
  FXHorizontalFrame *viewframe;
  FXVerticalFrame   *legendframe;
  FXVerticalFrame   *progressframe;
  FXHorizontalFrame *buttonsframe;
  FXHorizontalFrame *wheelframe;
  FXHorizontalFrame *infoframe;

  FXDirList  	*dirlist;
  FXFileList	*filelist;
  FXList	*viewlist;
  FXTextField	*linelist;
#ifdef HAVE_LIBFOX_1_7
  FXFileAssociations *associations;
#elif HAVE_LIBFOX_1_6
  FXFileDict *associations;
#endif
  FXMenuBar   *menubar;

  FXMenuPane  *menu_arrange;
  FXMenuTitle *title_arrange;
  FXMenuRadio *radio_det;
  FXMenuRadio *radio_sma;
  FXMenuRadio *radio_big;

  FXMenuPane  *menu_show;
  FXMenuTitle *title_show;
  FXMenuCheck *check_fil;
  FXMenuCheck *check_dir;

  FXMenuPane  *menu_about;
  FXMenuTitle *title_about;
  FXMenuCommand *cmd_about;

  FXLabel *infolabel_name;
  FXLabel *infolabel_msg;
  FXString s_infolabel;

  FXLabel *label_cu;
  FXLabel *label_su;
  FXLabel *label_in;
  FXLabel *label_cl;
  FXLabel *label_re;
  FXLabel *label_wheel1;
  FXLabel *label_wheel2;
  FXLabel *label_wheel3;
  FXLabel *label_wheel4;

  FXButton *button_sc;
  FXButton *button_qu;

  FXSplitter 	*splitterh;
  FXSplitter 	*splitterv;
  FXProgressBar *totalprogressbar;

  FXString  currentdir;
  FXString  filename;

  FXbool    initclamav;
  FXbool    flushclamav;
  FXint     totalprogress;

  FXString  fontspec;
  FXString  fontspec2;
  FXFont    *bodyfont;
  FXFont    *menufont;

  FXColor   theme_fxmmbase;
  FXColor   theme_fxmmborder;
  FXColor   theme_fxmmfore;
  FXColor   theme_fxmmselfore;
  FXColor   theme_fxmmmenufore;
  FXColor   theme_fxmmtipfore;
  FXColor   theme_fxmmback;
  FXColor   theme_fxmmselback;
  FXColor   theme_fxmmmenuback;
  FXColor   theme_fxmmtipback;
  FXColor   theme_fxmmhilite;
  FXColor   theme_fxmmshadow;
  
  FXString  language;
  FXString  file_n;
  FXString  file_t;
  FXString  file_s;
  FXString  file_m;
  FXString  file_u;
  FXString  file_g;
  FXString  file_a;
  FXString  file_l;


public:
  enum{
    ID_QUIT=FXMainWindow::ID_LAST,
    ID_MAINWIN,
    ID_SCAN,
    ID_FILELIST,
    ID_DIRLIST,
    ID_ABOUT,
    ID_INFO,
    ID_LAST
    };


public:
  // Message handlers
  long onCmdQuit(FXObject*,FXSelector,void*);
  long onCmdScan(FXObject*,FXSelector,void*);
  long onCmdDirlist(FXObject*,FXSelector,void* ptr);
  long onCmdFilelist(FXObject*,FXSelector,void* ptr);
  long onUpdTitleDir(FXObject* sender,FXSelector,void*);
  long onCmdAbout(FXObject*,FXSelector,void*);
  long onCmdInfo(FXObject*,FXSelector,void*);

public:
  // Construct dialog
  ScanVirusDialog(FXApp *);
  virtual void create();
  // Destroy
  virtual ~ScanVirusDialog();

  FXbool readConfig();
  int execScanVirus(FXFileList* panel, FXbool init);
  void scanFileName(int ret, const char *virname, struct cl_engine *engine, FXString& filetoscan, FXint i);
  void recurUpdFilelist(int ret, const char *virname, struct cl_engine *engine, const FXString& dirname);
  void setDirectory(const FXString& dirname);
  void recurUpdProgress(const FXString& dirname);
  void updTotalProgress(FXint progress);
  void updTitleProgress();
  void updIconsProgress();

  void quitApp();

  };

#endif
