/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 6.5                   *
*********************************************************************************
* Id: fileinputdialog.cpp,                        2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/

#include <xincs.h>
#include <fx.h>
#include "config.h"
#include "icons.h"
#include "FileInputDialog.h"

// Map
FXDEFMAP(FileInputDialog) FileInputDialogMap[]={
  FXMAPFUNC(SEL_COMMAND,  FileInputDialog::ID_CANCEL,                                              FileInputDialog::onCmdCancel),
  FXMAPFUNC(SEL_COMMAND,  FileInputDialog::ID_ACCEPT,                                              FileInputDialog::onCmdAccept),
  FXMAPFUNCS(SEL_COMMAND, FileInputDialog::ID_EXACT_TEXT, FileInputDialog::ID_CONTAIN_NOCASE_TEXT, FileInputDialog::onCmdOptions),
  FXMAPFUNCS(SEL_UPDATE,  FileInputDialog::ID_EXACT_TEXT, FileInputDialog::ID_CONTAIN_NOCASE_TEXT, FileInputDialog::onUpdOptions),
  };

// Object implementation
FXIMPLEMENT(FileInputDialog,FXDialogBox,FileInputDialogMap,ARRAYNUMBER(FileInputDialogMap))


// Create dialog
FileInputDialog::FileInputDialog(FXWindow *own)
  :FXDialogBox(own,"File Search",DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,0,0,0,0, 4,4,4,4, 4,4){
  cancelicon=new FXGIFIcon(getApp(),m_cancel);
  accepticon=new FXGIFIcon(getApp(),m_accept);

  dialogframe=new FXVerticalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_THICK|FRAME_SUNKEN, 0,0,0,0, 0,0,0,0,0,0);
  // text input
  inputframe=new FXHorizontalFrame(dialogframe,LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_CENTER_Y,0,0,0,0, 0,0,0,0, 10,10);
  matrix=new FXMatrix(inputframe,2,MATRIX_BY_COLUMNS|PACK_UNIFORM_WIDTH|PACK_UNIFORM_HEIGHT|LAYOUT_FILL_X|LAYOUT_FILL_Y);
  new FXLabel(matrix,tr("FIND NAME IN FILE:"),NULL,JUSTIFY_LEFT|ICON_BEFORE_TEXT|LAYOUT_TOP|LAYOUT_LEFT|LAYOUT_FILL_X,0,0,0,0, 3,3,3,3);
  input=new FXTextField(matrix,18,NULL,0,TEXTFIELD_NORMAL|JUSTIFY_RIGHT,0,0,0,0, 3,3,3,3);
  new FXLabel(matrix,"",NULL,LAYOUT_FILL_X,0,0,0,0, 3,3,3,3);
  new FXLabel(matrix,"",NULL,LAYOUT_FILL_X,0,0,0,0, 3,3,3,3);
  // buttons
  new FXButton(matrix,tr("&CANCEL"),cancelicon,this,ID_CANCEL,BUTTON_DEFAULT|BUTTON_NORMAL|LAYOUT_CENTER_X|LAYOUT_CENTER_Y,0,0,0,0,10,10);
  new FXButton(matrix,tr("&ACCEPT"),accepticon,this,ID_ACCEPT,BUTTON_NORMAL|LAYOUT_CENTER_X|LAYOUT_CENTER_Y,0,0,0,0,10,10);
  // controls
  group=new FXGroupBox(inputframe,"Search Options",GROUPBOX_TITLE_CENTER|FRAME_RIDGE);
  new FXRadioButton(group,"Match Exact",this,ID_EXACT_TEXT);
  new FXRadioButton(group,"Match Ignore Case",this,ID_NOCASE_TEXT);
  new FXRadioButton(group,"Contains Exact",this,ID_CONTAIN_TEXT);
  new FXRadioButton(group,"Contains Ignore Case",this,ID_CONTAIN_NOCASE_TEXT);
  // copyright
  new FXSeparator(dialogframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame *copyright=new FXHorizontalFrame(dialogframe,LAYOUT_BOTTOM|LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  FXLabel *label = new FXLabel(copyright,"FXMovieManager - File Search Engine",NULL,LAYOUT_FILL_X|LAYOUT_CENTER_Y|JUSTIFY_LEFT,0,0,0,0,15);
  // set the same look of separators
  label->disable();
  src_opt=0;
  }


// Destroy
FileInputDialog::~FileInputDialog(){
  delete cancelicon;
  delete accepticon;
  }


// Obtain the input string and the search option
FXbool FileInputDialog::getString(FXString& result, FXuint& opt, FXWindow* owner){
  FileInputDialog inputdialog(owner);
  inputdialog.setText(result);
  if(inputdialog.execute(PLACEMENT_OWNER)){
    result=inputdialog.getText();
    opt=inputdialog.getOption();
    return true;
    }
  return false;
  }


// We have to do this so as to force the initial text to be seleced
FXuint FileInputDialog::execute(FXuint placement){
  create();
  input->setFocus();
  input->selectAll();
  show(placement);
  return getApp()->runModalFor(this);
  }

// get the search option
long FileInputDialog::onCmdOptions(FXObject* sender,FXSelector sel,void* ptr){
  switch(FXSELID(sel)){
    case ID_EXACT_TEXT:
      src_opt=0;
      break;
    case ID_NOCASE_TEXT:
      src_opt=1;
     break;
    case ID_CONTAIN_TEXT:
      src_opt=2;
      break;
    case ID_CONTAIN_NOCASE_TEXT:
      src_opt=3;
      break;
  }
  return 1;
  }

// get the search option
long FileInputDialog::onUpdOptions(FXObject* sender,FXSelector sel,void* ptr){
  FXSelector updatemessage=FXSEL(SEL_COMMAND,ID_UNCHECK);
  switch(FXSELID(sel)){
    case ID_EXACT_TEXT:
      if(src_opt==0) updatemessage=FXSEL(SEL_COMMAND,ID_CHECK);
      break;
    case ID_NOCASE_TEXT:
      if(src_opt==1) updatemessage=FXSEL(SEL_COMMAND,ID_CHECK);
     break;
    case ID_CONTAIN_TEXT:
      if(src_opt==2) updatemessage=FXSEL(SEL_COMMAND,ID_CHECK);
      break;
    case ID_CONTAIN_NOCASE_TEXT:
      if(src_opt==3) updatemessage=FXSEL(SEL_COMMAND,ID_CHECK);
      break;
  }
  sender->handle(this,updatemessage,NULL);
  return 1;
  }


// get the search option
long FileInputDialog::onCmdAccept(FXObject* sender,FXSelector sel,void* ptr){
  input->setFocus();
  input->selectAll();
  FXDialogBox::onCmdAccept(sender,sel,ptr);
  return 1;
  }

// get the search option
long FileInputDialog::onCmdCancel(FXObject* sender,FXSelector sel,void* ptr){
  FXDialogBox::onCmdCancel(sender,sel,ptr);
  return 1;
  }

