/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 6.5                   *
*********************************************************************************
* Id: fileinputdialog.h,                          2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/

#ifndef FILEINPUTDIALOG_H
#define FILEINPUTDIALOG_H

//! The fileinputdialog class 

class FileInputDialog : public FXDialogBox {
  FXDECLARE(FileInputDialog)

protected:
  FXIcon *cancelicon;
  FXIcon *accepticon;
  FXVerticalFrame *dialogframe;
  FXHorizontalFrame *inputframe;
  FXHorizontalFrame *buttonframe;
  FXMatrix *matrix;
  FXTextField *input;
  FXGroupBox* group;
  FXuint src_opt;


protected:
  FileInputDialog(){};
private:
  FileInputDialog(const FileInputDialog&){};
  FileInputDialog &operator=(const FileInputDialog&){};

public:
  long onCmdAccept(FXObject*,FXSelector,void*);
  long onCmdCancel(FXObject*,FXSelector,void*);
  long onCmdOptions(FXObject*,FXSelector,void*);
  long onUpdOptions(FXObject*,FXSelector,void*);

public:
  enum{
    ID_ACCEPT=FXMainWindow::ID_LAST,
	ID_CANCEL,
	ID_EXACT_TEXT,
	ID_NOCASE_TEXT,
	ID_CONTAIN_TEXT,
	ID_CONTAIN_NOCASE_TEXT,
    ID_LAST
    };

public:
  // Construct the dialog
  FileInputDialog(FXWindow *owner);
  // Run modal invocation of the dialog
  FXuint execute(FXuint placement=PLACEMENT_CURSOR);
  // Get the search option
  FXuint getOption() const { return src_opt; }
  // Get input string
  FXString getText() const { return input->getText(); }
  // Set input string
  void setText(const FXString& text){ input->setText(text); }
  // Prompt for the string and the search option, starting with an initial text.
  // Return true if the new text and the option is accepted, and false otherwise.
  static FXbool getString(FXString& result, FXuint& opt, FXWindow* owner);
  // Destroy
  virtual ~FileInputDialog();
  };

#endif
