/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 6.5                   *
*********************************************************************************
* Id: languagedialog.cpp,                         2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/
#include <fx.h>
#include "LanguageDialog.h"
#include "icons.h"

FXDEFMAP(LanguageDialog) LanguageDialogMap[] = {
	//____Message_Type______________ID_________________Message_Handler______
	FXMAPFUNC(SEL_COMMAND,	LanguageDialog::ID_READ,     LanguageDialog::onCmdRead),
	FXMAPFUNC(SEL_COMMAND,	LanguageDialog::ID_WRITE,    LanguageDialog::onCmdWrite),
    FXMAPFUNC(SEL_COMMAND,  LanguageDialog::ID_PANEL,    LanguageDialog::onCmdPanel),
};

// LanguageDialog implementation
FXIMPLEMENT(LanguageDialog, FXDialogBox, LanguageDialogMap, ARRAYNUMBER(LanguageDialogMap))


// Construct a dialog box
LanguageDialog::LanguageDialog(FXWindow* owner)
	:FXDialogBox(owner,"Mencoder Configuration", DECOR_TITLE|DECOR_BORDER){

  // set icon on the main window
  read_icon=new FXGIFIcon(getApp(),b_conf);
  write_icon=new FXGIFIcon(getApp(),b_list);
  quit_icon=new FXGIFIcon(getApp(),b_quit);
  setIcon(read_icon);


  // Bottom buttons
  buttons=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|FRAME_NONE|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,2,2);

  // Separator
  //new FXHorizontalSeparator(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|SEPARATOR_GROOVE);

  // Contents
  contents=new FXHorizontalFrame(this,LAYOUT_SIDE_TOP|FRAME_NONE|LAYOUT_FILL_X|LAYOUT_FILL_Y|PACK_UNIFORM_WIDTH);

  // Switcher
  tabbook=new FXTabBook(contents,this,ID_PANEL,PACK_UNIFORM_WIDTH|PACK_UNIFORM_HEIGHT|LAYOUT_FILL_X|LAYOUT_FILL_Y|LAYOUT_RIGHT);


  tab1=new FXTabItem(tabbook,"&Help_Custom",NULL);
  FXMatrix *help_mat=new FXMatrix(tabbook,4,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y);

  p_quitbuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_quitbuttontext->setText("Quit  ");
  t_quitbuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_quitbuttontext->setText("Quit the application");

  p_openbuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_openbuttontext->setText("Add   ");
  t_openbuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_openbuttontext->setText("Add movies to the playlist");

  p_stopbuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_stopbuttontext->setText("Stop  ");
  t_stopbuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_stopbuttontext->setText("Stop the Player");

  p_pausebuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_pausebuttontext->setText("Pause ");
  t_pausebuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_pausebuttontext->setText("Pause the Player");

  p_playbuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_playbuttontext->setText("Play  ");
  t_playbuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_playbuttontext->setText("Play the selected movies");

  p_jplaybuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_jplaybuttontext->setText("View  ");
  t_jplaybuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_jplaybuttontext->setText("View as slideshow");

  p_audiobuttontext1=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_audiobuttontext1->setText("Mute  ");
  t_audiobuttontext1=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_audiobuttontext1->setText("Mute the Player");

  p_audiobuttontext2=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_audiobuttontext2->setText("Audio ");
  t_audiobuttontext2=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_audiobuttontext2->setText("Audio is allowed");

  p_dropbuttontext1=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_dropbuttontext1->setText("Drop  ");
  t_dropbuttontext1=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_dropbuttontext1->setText("Drop frames");

  p_dropbuttontext2=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_dropbuttontext2->setText("All   ");
  t_dropbuttontext2=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_dropbuttontext2->setText("All frames");

  p_loopbuttontext1=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_loopbuttontext1->setText("Loop  ");
  t_loopbuttontext1=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_loopbuttontext1->setText("Play in loop");

  p_loopbuttontext2=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_loopbuttontext2->setText("Once  ");
  t_loopbuttontext2=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_loopbuttontext2->setText("Play once");

  p_zoombuttontext1=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_zoombuttontext1->setText("Zoom  ");
  t_zoombuttontext1=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_zoombuttontext1->setText("Zoom video size");

  p_zoombuttontext2=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_zoombuttontext2->setText("1:1   ");
  t_zoombuttontext2=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_zoombuttontext2->setText("Real video size");

  p_hidebuttontext1=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_hidebuttontext1->setText("Hide  ");
  t_hidebuttontext1=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_hidebuttontext1->setText("Hide the playlist");

  p_hidebuttontext2=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_hidebuttontext2->setText("Show  ");
  t_hidebuttontext2=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_hidebuttontext2->setText("Show the playlist");

  p_outputbuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_outputbuttontext->setText("Output");
  t_outputbuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_outputbuttontext->setText("Video output");

  p_sizebuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_sizebuttontext->setText("Size  ");
  t_sizebuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_sizebuttontext->setText("Video size");

  p_confbuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_confbuttontext->setText("Config");
  t_confbuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_confbuttontext->setText("FxMovieManager Configuration");

  p_upbuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_upbuttontext->setText("GoUp  ");
  t_upbuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_upbuttontext->setText("Move one step up");

  p_downbuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_downbuttontext->setText("GoDown");
  t_downbuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_downbuttontext->setText("Move one step down");

  p_slistbuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_slistbuttontext->setText("Save  ");
  t_slistbuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_slistbuttontext->setText("Save list of movies");

  p_olistbuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_olistbuttontext->setText("Load  ");
  t_olistbuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_olistbuttontext->setText("Load list of movies");

  p_allbuttontext1=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_allbuttontext1->setText("Select");
  t_allbuttontext1=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_allbuttontext1->setText("Select all movies");

  p_allbuttontext2=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_allbuttontext2->setText("Desel ");
  t_allbuttontext2=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_allbuttontext2->setText("Deselect all movies");

  p_createbuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_createbuttontext->setText("Create");
  t_createbuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_createbuttontext->setText("Create thumbnails");

  p_recreatebuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_recreatebuttontext->setText("ReCrea");
  t_recreatebuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_recreatebuttontext->setText("Recreate thumbnails");

  p_widebuttontext1=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_widebuttontext1->setText("Wide  ");
  t_widebuttontext1=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_widebuttontext1->setText("Show Wide Screen Thumbnails");

  p_widebuttontext2=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_widebuttontext2->setText("Normal");
  t_widebuttontext2=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_widebuttontext2->setText("Show Normal Screen Thumbnails");

  p_imgbuttontext1=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_imgbuttontext1->setText("NoShow");
  t_imgbuttontext1=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_imgbuttontext1->setText("Don't show thumbnail images");

  p_imgbuttontext2=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_imgbuttontext2->setText("Show  ");
  t_imgbuttontext2=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_imgbuttontext2->setText("Show thumbnail images");

  p_deletebuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_deletebuttontext->setText("Delete");
  t_deletebuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_deletebuttontext->setText("Delete thumbnails");

  p_clearbuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_clearbuttontext->setText("Clear ");
  t_clearbuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_clearbuttontext->setText("Clear the playlist");

  p_increasebuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_increasebuttontext->setText("Increm");
  t_increasebuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_increasebuttontext->setText("Increase thumbnails size");

  p_decreasebuttontext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_decreasebuttontext->setText("Decrem");
  t_decreasebuttontext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_decreasebuttontext->setText("Decrease thumbnails size");

  p_icnlisttext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_icnlisttext->setText("Icons ");
  t_icnlisttext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_icnlisttext->setText("Icons list view");

  p_detlisttext=new FXTextField(help_mat,10,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  p_detlisttext->setText("Detail");
  t_detlisttext=new FXTextField(help_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_detlisttext->setText("Details list view");


  tab2=new FXTabItem(tabbook,"&Menu_Custom",NULL);
  FXMatrix *menu_mat=new FXMatrix(tabbook,3,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y);
  
  t_file_n=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_file_n->setText("Name");
  t_file_t=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_file_t->setText("Type");
  t_file_s=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_file_s->setText("Size");
  t_file_m=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_file_m->setText("Modified date");
  t_file_u=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_file_u->setText("User");
  t_file_g=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_file_g->setText("Group");
  t_file_a=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_file_a->setText("Permissions");
  t_file_l=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_file_l->setText("Symlink");

  t_menu_op=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_op->setText("Open");
  t_menu_ow=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_ow->setText("Open with");
  t_menu_pr=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_pr->setText("Properties");
  t_menu_mi=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_mi->setText("Properties");
  t_menu_re=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_re->setText("Rename");
  t_menu_mo=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_mo->setText("Move");
  t_menu_sy=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_sy->setText("Symlink");
  t_menu_cu=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_cu->setText("Cut");
  t_menu_co=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_co->setText("Copy");
  t_menu_pa=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_pa->setText("Paste");
  t_menu_de=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_de->setText("Delete");

  t_menu_te=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_te->setText("Terminal");
  t_menu_he=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_he->setText("Run here");
  t_menu_vi=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_vi->setText("Virus scanner");
  t_menu_ar=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_ar->setText("Archive opener");
  t_menu_sr=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_sr->setText("File finder");
  t_menu_sh=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_sh->setText("Show/Hide");
  t_menu_nd=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_nd->setText("New directory");
  t_menu_rd=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_rd->setText("Rename directory");
  t_menu_dd=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_dd->setText("Delete directory");
  t_menu_rf=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_rf->setText("Refresh");
  t_menu_sc=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_sc->setText("Search for devices");
  t_menu_ma=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_ma->setText("Connect device");
  t_menu_um=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_um->setText("Disconnect device");

  t_menu_up=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_up->setText("Move Up");
  t_menu_do=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_do->setText("Move Down");
  t_menu_al=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_al->setText("Select All");
  t_menu_da=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_da->setText("Delete All");
  t_menu_ap=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_ap->setText("Append Item");
  t_menu_in=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_in->setText("Insert Item");
  t_menu_di=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_di->setText("Delete Item");
  t_menu_ed=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_ed->setText("Edit Item Text");

  t_menu_cm=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_cm->setText("Compress");
  t_menu_ex=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_ex->setText("Extract");
  t_menu_ec=new FXTextField(menu_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_menu_ec->setText("Command");



  tab3=new FXTabItem(tabbook,"&Knobs_Custom",NULL);
  FXMatrix *knob_mat=new FXMatrix(tabbook,3,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y);  
  
  t_spebuttontext=new FXTextField(knob_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_spebuttontext->setText("Speed");
  t_volbuttontext=new FXTextField(knob_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_volbuttontext->setText("Volume");
  t_bributtontext=new FXTextField(knob_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_bributtontext->setText("Brightness");
  t_conbuttontext=new FXTextField(knob_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_conbuttontext->setText("Contrast");
  t_huebuttontext=new FXTextField(knob_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_huebuttontext->setText("Hue");
  t_satbuttontext=new FXTextField(knob_mat,30,NULL,0,TEXTFIELD_NORMAL|FRAME_SUNKEN|FRAME_THICK|LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
  t_satbuttontext->setText("Saturation");


  // Read button
  new FXButton(buttons,"&READ",read_icon,this,ID_READ,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y);
  // Write button
  new FXButton(buttons,"&WRITE",write_icon,this,ID_WRITE,BUTTON_DEFAULT|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y);
  // Cancel button
  new FXButton(buttons,"&CLOSE",quit_icon,this,ID_CANCEL,BUTTON_DEFAULT|BUTTON_INITIAL|FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y);
}

// Must delete the menus
LanguageDialog::~LanguageDialog(){
  delete read_icon;
  delete write_icon;
  delete quit_icon;
}

// read data from file
void LanguageDialog::readData(){

  // Read language
  audiobuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","audiobuttontext1");
  audiobuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","audiobuttontext2");
  dropbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","dropbuttontext1");
  dropbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","dropbuttontext2");
  zoombuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","zoombuttontext1");
  zoombuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","zoombuttontext2");
  loopbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","loopbuttontext1");
  loopbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","loopbuttontext2");
  hidebuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","hidebuttontext1");
  hidebuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","hidebuttontext2");
  allbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","allbuttontext1");
  allbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","allbuttontext2");
  widebuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","widebuttontext1");
  widebuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","widebuttontext2");
  imgbuttontext1=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","imgbuttontext1");
  imgbuttontext2=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","imgbuttontext2");
  quitbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","quitbuttontext");
  openbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","openbuttontext");
  stopbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","stopbuttontext");
  pausebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","pausebuttontext");
  playbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","playbuttontext");
  jplaybuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","jplaybuttontext");
  outputbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","outputbuttontext");
  sizebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","sizebuttontext");
  confbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","confbuttontext");
  upbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","upbuttontext");
  downbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","downbuttontext");
  slistbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","slistbuttontext");
  olistbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","olistbuttontext");
  createbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","createbuttontext");
  recreatebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","recreatebuttontext");
  deletebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","deletebuttontext");
  clearbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","clearbuttontext");
  increasebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","increasebuttontext");
  decreasebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","decreasebuttontext");
  icnlisttext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","icnlisttext");
  detlisttext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","detlisttext");

  spebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","spebuttontext");
  volbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","volbuttontext");
  bributtontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","bributtontext");
  conbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","conbuttontext");
  huebuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","huebuttontext");
  satbuttontext=getApp()->reg().readStringEntry("LANG_BUTTON_CUSTOM","satbuttontext");  

  file_n=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_n");
  file_t=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_t");
  file_s=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_s");
  file_m=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_m");
  file_u=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_u");
  file_g=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_g");
  file_a=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_a");
  file_l=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","file_l");

  menu_op=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_op");
  menu_ow=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ow");
  menu_pr=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_pr");
  menu_mi=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_mi");
  menu_re=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_re");
  menu_mo=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_mo");
  menu_sy=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_sy");
  menu_cu=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_cu");
  menu_co=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_co");
  menu_pa=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_pa");
  menu_de=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_de");

  menu_te=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_te");
  menu_he=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_he");
  menu_vi=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_vi");
  menu_ar=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ar");
  menu_sr=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_sr");
  menu_sh=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_sh");
  menu_nd=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_nd");
  menu_rd=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_rd");
  menu_dd=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_dd");
  menu_rf=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_rf");
  menu_sc=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_sc");
  menu_ma=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ma");
  menu_um=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_um");

  menu_up=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_up");
  menu_do=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_do");
  menu_al=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_al");
  menu_da=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_da");
  menu_ap=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ap");
  menu_in=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_in");
  menu_di=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_di");
  menu_ed=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ed");

  menu_cm=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_cm");
  menu_ex=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ex");
  menu_ec=getApp()->reg().readStringEntry("LANG_MENU_CUSTOM","menu_ec");

  // Read registry settings
  getApp()->reg().read();
}


long LanguageDialog::onCmdRead(FXObject *,FXSelector,void *){

	readData();

    p_audiobuttontext1->setText(audiobuttontext1.mid(1,10));
    t_audiobuttontext1->setText(audiobuttontext1.mid(12,42));
    p_audiobuttontext2->setText(audiobuttontext2.mid(1,10));
    t_audiobuttontext2->setText(audiobuttontext2.mid(12,42));
 
    p_dropbuttontext1->setText(dropbuttontext1.mid(1,10));
    t_dropbuttontext1->setText(dropbuttontext1.mid(12,42));
    p_dropbuttontext2->setText(dropbuttontext2.mid(1,10));
    t_dropbuttontext2->setText(dropbuttontext2.mid(12,42));

    p_zoombuttontext1->setText(zoombuttontext1.mid(1,10));
    t_zoombuttontext1->setText(zoombuttontext1.mid(12,42));
    p_zoombuttontext2->setText(zoombuttontext2.mid(1,10));
    t_zoombuttontext2->setText(zoombuttontext2.mid(12,42));

    p_loopbuttontext1->setText(loopbuttontext1.mid(1,10));
    t_loopbuttontext1->setText(loopbuttontext1.mid(12,42));
    p_loopbuttontext2->setText(loopbuttontext2.mid(1,10));
    t_loopbuttontext2->setText(loopbuttontext2.mid(12,42));

    p_hidebuttontext1->setText(hidebuttontext1.mid(1,10));
    t_hidebuttontext1->setText(hidebuttontext1.mid(12,42));
    p_hidebuttontext2->setText(hidebuttontext2.mid(1,10));
    t_hidebuttontext2->setText(hidebuttontext2.mid(12,42));

    p_allbuttontext1->setText(allbuttontext1.mid(1,10));
    t_allbuttontext1->setText(allbuttontext1.mid(12,42));
    p_allbuttontext2->setText(allbuttontext2.mid(1,10));
    t_allbuttontext2->setText(allbuttontext2.mid(12,42));

    p_widebuttontext1->setText(widebuttontext1.mid(1,10));
    t_widebuttontext1->setText(widebuttontext1.mid(12,42));
    p_widebuttontext2->setText(widebuttontext2.mid(1,10));
    t_widebuttontext2->setText(widebuttontext2.mid(12,42));

    p_imgbuttontext1->setText(imgbuttontext1.mid(1,10));
    t_imgbuttontext1->setText(imgbuttontext1.mid(12,42));
    p_imgbuttontext2->setText(imgbuttontext2.mid(1,10));
    t_imgbuttontext2->setText(imgbuttontext2.mid(12,42));

    p_quitbuttontext->setText(quitbuttontext.mid(1,10));
    t_quitbuttontext->setText(quitbuttontext.mid(12,42));

    p_openbuttontext->setText(openbuttontext.mid(1,10));
    t_openbuttontext->setText(openbuttontext.mid(12,42));

    p_stopbuttontext->setText(stopbuttontext.mid(1,10));
    t_stopbuttontext->setText(stopbuttontext.mid(12,42));

    p_pausebuttontext->setText(pausebuttontext.mid(1,10));
    t_pausebuttontext->setText(pausebuttontext.mid(12,42));

    p_playbuttontext->setText(playbuttontext.mid(1,10));
    t_playbuttontext->setText(playbuttontext.mid(12,42));

    p_jplaybuttontext->setText(jplaybuttontext.mid(1,10));
    t_jplaybuttontext->setText(jplaybuttontext.mid(12,42));

    p_outputbuttontext->setText(outputbuttontext.mid(1,10));
    t_outputbuttontext->setText(outputbuttontext.mid(12,42));

    p_sizebuttontext->setText(sizebuttontext.mid(1,10));
    t_sizebuttontext->setText(sizebuttontext.mid(12,42));

    p_confbuttontext->setText(confbuttontext.mid(1,10));
    t_confbuttontext->setText(confbuttontext.mid(12,42));

    p_upbuttontext->setText(upbuttontext.mid(1,10));
    t_upbuttontext->setText(upbuttontext.mid(12,42));

    p_downbuttontext->setText(downbuttontext.mid(1,10));
    t_downbuttontext->setText(downbuttontext.mid(12,42));

    p_slistbuttontext->setText(slistbuttontext.mid(4,10));
    t_slistbuttontext->setText(slistbuttontext.mid(15,42));

    p_olistbuttontext->setText(olistbuttontext.mid(4,10));
    t_olistbuttontext->setText(olistbuttontext.mid(15,42));

    p_createbuttontext->setText(createbuttontext.mid(1,10));
    t_createbuttontext->setText(createbuttontext.mid(12,42));

    p_recreatebuttontext->setText(recreatebuttontext.mid(1,10));
    t_recreatebuttontext->setText(recreatebuttontext.mid(12,42));

    p_deletebuttontext->setText(deletebuttontext.mid(1,10));
    t_deletebuttontext->setText(deletebuttontext.mid(12,42));

    p_clearbuttontext->setText(clearbuttontext.mid(1,10));
    t_clearbuttontext->setText(clearbuttontext.mid(12,42));

    p_increasebuttontext->setText(increasebuttontext.mid(1,10));
    t_increasebuttontext->setText(increasebuttontext.mid(12,42));

    p_decreasebuttontext->setText(decreasebuttontext.mid(1,10));
    t_decreasebuttontext->setText(decreasebuttontext.mid(12,42));

    p_icnlisttext->setText(icnlisttext.mid(1,10));
    t_icnlisttext->setText(icnlisttext.mid(12,42));

    p_detlisttext->setText(detlisttext.mid(1,10));
    t_detlisttext->setText(detlisttext.mid(12,42));

	t_spebuttontext->setText(spebuttontext);
	t_volbuttontext->setText(volbuttontext);
	t_bributtontext->setText(bributtontext);
	t_conbuttontext->setText(conbuttontext);
	t_huebuttontext->setText(huebuttontext);
	t_satbuttontext->setText(satbuttontext);

	t_file_n->setText(file_n);
	t_file_t->setText(file_t);
	t_file_s->setText(file_s);
	t_file_m->setText(file_m);
	t_file_u->setText(file_u);
	t_file_g->setText(file_g);
	t_file_a->setText(file_a);
	t_file_l->setText(file_l);

	t_menu_op->setText(menu_op);
	t_menu_ow->setText(menu_ow);
	t_menu_pr->setText(menu_pr);
	t_menu_mi->setText(menu_mi);
	t_menu_re->setText(menu_re);
	t_menu_mo->setText(menu_mo);
	t_menu_sy->setText(menu_sy);
	t_menu_cu->setText(menu_cu);
	t_menu_co->setText(menu_co);
	t_menu_pa->setText(menu_pa);
	t_menu_de->setText(menu_de);

	t_menu_te->setText(menu_te);
	t_menu_he->setText(menu_he);
	t_menu_vi->setText(menu_vi);
	t_menu_ar->setText(menu_ar);
	t_menu_sr->setText(menu_sr);
	t_menu_sh->setText(menu_sh);
	t_menu_nd->setText(menu_nd);
	t_menu_rd->setText(menu_rd);
	t_menu_dd->setText(menu_dd);
	t_menu_rf->setText(menu_rf);
	t_menu_sc->setText(menu_sc);
	t_menu_ma->setText(menu_ma);
	t_menu_um->setText(menu_um);

	t_menu_up->setText(menu_up);
	t_menu_do->setText(menu_do);
	t_menu_al->setText(menu_al);
	t_menu_da->setText(menu_da);
	t_menu_ap->setText(menu_ap);
	t_menu_in->setText(menu_in);
	t_menu_di->setText(menu_di);
	t_menu_ed->setText(menu_ed);

	t_menu_cm->setText(menu_cm);
	t_menu_ex->setText(menu_ex);
	t_menu_ec->setText(menu_ec);

	return 1;
}



// write data to file
void LanguageDialog::writeData(){

  // Write language
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","audiobuttontext1",audiobuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","audiobuttontext2",audiobuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","dropbuttontext1",dropbuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","dropbuttontext2",dropbuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","zoombuttontext1",zoombuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","zoombuttontext2",zoombuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","loopbuttontext1",loopbuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","loopbuttontext2",loopbuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","hidebuttontext1",hidebuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","hidebuttontext2",hidebuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","allbuttontext1",allbuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","allbuttontext2",allbuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","widebuttontext1",widebuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","widebuttontext2",widebuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","imgbuttontext1",imgbuttontext1.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","imgbuttontext2",imgbuttontext2.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","quitbuttontext",quitbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","openbuttontext",openbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","stopbuttontext",stopbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","pausebuttontext",pausebuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","playbuttontext",playbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","jplaybuttontext",jplaybuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","outputbuttontext",outputbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","sizebuttontext",sizebuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","confbuttontext",confbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","upbuttontext",upbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","downbuttontext",downbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","slistbuttontext",slistbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","olistbuttontext",olistbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","createbuttontext",createbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","recreatebuttontext",recreatebuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","deletebuttontext",deletebuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","clearbuttontext",clearbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","increasebuttontext",increasebuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","decreasebuttontext",decreasebuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","icnlisttext",icnlisttext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","detlisttext",detlisttext.text());

  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","spebuttontext",spebuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","volbuttontext",volbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","bributtontext",bributtontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","conbuttontext",conbuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","huebuttontext",huebuttontext.text());
  getApp()->reg().writeStringEntry("LANG_BUTTON_CUSTOM","satbuttontext",satbuttontext.text());  

  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","file_n",file_n.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","file_t",file_t.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","file_s",file_s.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","file_m",file_m.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","file_u",file_u.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","file_g",file_g.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","file_a",file_a.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","file_l",file_l.text());

  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_op",menu_op.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_ow",menu_ow.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_pr",menu_pr.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_mi",menu_mi.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_re",menu_re.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_mo",menu_mo.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_sy",menu_sy.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_cu",menu_cu.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_co",menu_co.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_pa",menu_pa.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_de",menu_de.text());

  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_te",menu_te.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_he",menu_he.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_vi",menu_vi.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_ar",menu_ar.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_sr",menu_sr.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_sh",menu_sh.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_nd",menu_nd.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_rd",menu_rd.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_dd",menu_dd.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_rf",menu_rf.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_sc",menu_sc.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_ma",menu_ma.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_um",menu_um.text());

  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_up",menu_up.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_do",menu_do.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_al",menu_al.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_da",menu_da.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_ap",menu_ap.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_in",menu_in.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_di",menu_di.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_ed",menu_ed.text());

  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_cm",menu_cm.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_ex",menu_ex.text());
  getApp()->reg().writeStringEntry("LANG_MENU_CUSTOM","menu_ec",menu_ec.text());

  // Write registry settings
  getApp()->reg().write();
}

long LanguageDialog::onCmdWrite(FXObject *,FXSelector,void *){
  // get text
    audiobuttontext1="\t"+autoFill(p_audiobuttontext1->getText())+"\t"+t_audiobuttontext1->getText();
    audiobuttontext2="\t"+autoFill(p_audiobuttontext2->getText())+"\t"+t_audiobuttontext2->getText();
    dropbuttontext1="\t"+autoFill(p_dropbuttontext1->getText())+"\t"+t_dropbuttontext1->getText();
    dropbuttontext2="\t"+autoFill(p_dropbuttontext2->getText())+"\t"+t_dropbuttontext2->getText();
    zoombuttontext1="\t"+autoFill(p_zoombuttontext1->getText())+"\t"+t_zoombuttontext1->getText();
    zoombuttontext2="\t"+autoFill(p_zoombuttontext2->getText())+"\t"+t_zoombuttontext2->getText();
    loopbuttontext1="\t"+autoFill(p_loopbuttontext1->getText())+"\t"+t_loopbuttontext1->getText();
    loopbuttontext2="\t"+autoFill(p_loopbuttontext2->getText())+"\t"+t_loopbuttontext2->getText();
    hidebuttontext1="\t"+autoFill(p_hidebuttontext1->getText())+"\t"+t_hidebuttontext1->getText();
    hidebuttontext2="\t"+autoFill(p_hidebuttontext2->getText())+"\t"+t_hidebuttontext2->getText();
    allbuttontext1="\t"+autoFill(p_allbuttontext1->getText())+"\t"+t_allbuttontext1->getText();
    allbuttontext2="\t"+autoFill(p_allbuttontext2->getText())+"\t"+t_allbuttontext2->getText();
    widebuttontext1="\t"+autoFill(p_widebuttontext1->getText())+"\t"+t_widebuttontext1->getText();
    widebuttontext2="\t"+autoFill(p_widebuttontext2->getText())+"\t"+t_widebuttontext2->getText();
    imgbuttontext1="\t"+autoFill(p_imgbuttontext1->getText())+"\t"+t_imgbuttontext1->getText();
    imgbuttontext2="\t"+autoFill(p_imgbuttontext2->getText())+"\t"+t_imgbuttontext2->getText();
    quitbuttontext="\t"+autoFill(p_quitbuttontext->getText())+"\t"+t_quitbuttontext->getText();
    openbuttontext="\t"+autoFill(p_openbuttontext->getText())+"\t"+t_openbuttontext->getText();
    stopbuttontext="\t"+autoFill(p_stopbuttontext->getText())+"\t"+t_stopbuttontext->getText();
    pausebuttontext="\t"+autoFill(p_pausebuttontext->getText())+"\t"+t_pausebuttontext->getText();
    playbuttontext="\t"+autoFill(p_playbuttontext->getText())+"\t"+t_playbuttontext->getText();
    jplaybuttontext="\t"+autoFill(p_jplaybuttontext->getText())+"\t"+t_jplaybuttontext->getText();
    outputbuttontext="\t"+autoFill(p_outputbuttontext->getText())+"\t"+t_outputbuttontext->getText();
    sizebuttontext="\t"+autoFill(p_sizebuttontext->getText())+"\t"+t_sizebuttontext->getText();
    confbuttontext="\t"+autoFill(p_confbuttontext->getText())+"\t"+t_confbuttontext->getText();
    upbuttontext="\t"+autoFill(p_upbuttontext->getText())+"\t"+t_upbuttontext->getText();
    downbuttontext="\t"+autoFill(p_downbuttontext->getText())+"\t"+t_downbuttontext->getText();
    slistbuttontext="|_|\t"+autoFill(p_slistbuttontext->getText())+"\t"+t_slistbuttontext->getText();
    olistbuttontext="||>\t"+autoFill(p_olistbuttontext->getText())+"\t"+t_olistbuttontext->getText();
    createbuttontext="\t"+autoFill(p_createbuttontext->getText())+"\t"+t_createbuttontext->getText();
    recreatebuttontext="\t"+autoFill(p_recreatebuttontext->getText())+"\t"+t_recreatebuttontext->getText();
    deletebuttontext="\t"+autoFill(p_deletebuttontext->getText())+"\t"+t_deletebuttontext->getText();
    clearbuttontext="\t"+autoFill(p_clearbuttontext->getText())+"\t"+t_clearbuttontext->getText();
    increasebuttontext="\t"+autoFill(p_increasebuttontext->getText())+"\t"+t_increasebuttontext->getText();
    decreasebuttontext="\t"+autoFill(p_decreasebuttontext->getText())+"\t"+t_decreasebuttontext->getText();
    icnlisttext="\t"+autoFill(p_icnlisttext->getText())+"\t"+t_icnlisttext->getText();
    detlisttext="\t"+autoFill(p_detlisttext->getText())+"\t"+t_detlisttext->getText();
	
	spebuttontext=t_spebuttontext->getText();
	volbuttontext=t_volbuttontext->getText();
	bributtontext=t_bributtontext->getText();
	conbuttontext=t_conbuttontext->getText();
	huebuttontext=t_huebuttontext->getText();
	satbuttontext=t_satbuttontext->getText();

	file_n=t_file_n->getText();
	file_t=t_file_t->getText();
	file_s=t_file_s->getText();
	file_m=t_file_m->getText();
	file_u=t_file_u->getText();
	file_g=t_file_g->getText();
	file_a=t_file_a->getText();
	file_l=t_file_l->getText();

	menu_op=t_menu_op->getText();
	menu_ow=t_menu_ow->getText();
	menu_pr=t_menu_pr->getText();
	menu_mi=t_menu_mi->getText();
	menu_re=t_menu_re->getText();
	menu_mo=t_menu_mo->getText();
	menu_sy=t_menu_sy->getText();
	menu_cu=t_menu_cu->getText();
	menu_co=t_menu_co->getText();
	menu_pa=t_menu_pa->getText();
	menu_de=t_menu_de->getText();

	menu_te=t_menu_te->getText();
	menu_he=t_menu_he->getText();
	menu_vi=t_menu_vi->getText();
	menu_ar=t_menu_ar->getText();
	menu_sr=t_menu_sr->getText();
	menu_sh=t_menu_sh->getText();
	menu_nd=t_menu_nd->getText();
	menu_rd=t_menu_rd->getText();
	menu_dd=t_menu_dd->getText();
	menu_rf=t_menu_rf->getText();
	menu_sc=t_menu_sc->getText();
	menu_ma=t_menu_ma->getText();
	menu_um=t_menu_um->getText();

	menu_up=t_menu_up->getText();
	menu_do=t_menu_do->getText();
	menu_al=t_menu_al->getText();
	menu_da=t_menu_da->getText();
	menu_ap=t_menu_ap->getText();
	menu_in=t_menu_in->getText();
	menu_di=t_menu_di->getText();
	menu_ed=t_menu_ed->getText();

	menu_cm=t_menu_cm->getText();
	menu_ex=t_menu_ex->getText();
	menu_ec=t_menu_ec->getText();

	writeData();
	return 1;
}



// Active panel switched
long LanguageDialog::onCmdPanel(FXObject*,FXSelector,void* ptr){
    FXTRACE((1,"Panel = %d\n",(FXint)(FXival)ptr));
    return 1;
}

// Active panel switched
FXString LanguageDialog::autoFill(FXString item){
	if(item.count()>10){
		item=item.left(10);
	}

	while(item.count()<10){
		item.append(" ");
	}

    return item;
}


// EOF
