/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 6.5                   *
*********************************************************************************
* Id: mimetypedialog.h,                           2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/

#ifndef MIMETYPEDIALOG_H
#define MIMETYPEDIALOG_H

#include "config.h"

//! Here is created a new struct consistent with the one(FXFileAssoc) in FXFileDict.h
//! where are defined [FXString names] of icons instead of [*FXIcons]
//! because a subroutine will check for icons names and load images through [FXIconSource].

//! All the other types are preserved to be used with FXFileAssoc function. 
//! The type [command] is used to load the command association with the 
//! [open] option of the filelist pop-up menu.

//! Each entry of the struct in FXFileDict.h goes under the FILETYPES registry section
//! and contents-type will be imported, if they have been created with ControlPanel, 
//! because the present dialog is partially consistent with this program.

struct FileAssociation {
  FXString type;	    //! Type Name 
  FXString command;	    //! Command to open the file with (same of FXFileDict.h)
  FXString extension;       //! Full extension name (same of FXFileDict.h)
  FXString mimetype;        //! Content-Type [object/format] (same of FXFileDict.h)
  FXString bigname;	    //! Name of Big normal icon
  FXString smallname;       //! Name of Small normal icon
  };

class LanguageDialog;

class MimeTypeDialog : public FXDialogBox {
  FXDECLARE(MimeTypeDialog)

protected:
  LanguageDialog *languagedialog;

  // button icons for selection
  FXIcon 	*classicicon;
  FXIcon 	*darkicon;
  FXIcon 	*shineicon;
  FXIcon 	*citrusicon;
  FXIcon 	*orangeicon;
  FXIcon 	*noelicon;
  FXIcon 	*pinkicon;
  FXIcon 	*grassicon;
  FXIcon 	*watericon;
  FXIcon 	*skyicon;
  // flags icons for language selection
  FXIcon	*en_flagicon;
  FXIcon	*it_flagicon;
  FXIcon	*de_flagicon;
  FXIcon	*fr_flagicon;
  FXIcon	*es_flagicon;
  FXIcon	*ru_flagicon;
  FXIcon	*cn_flagicon;
  FXIcon	*jp_flagicon;

  // buttons for icons 
  FXButton  	*classicbutton;
  FXButton  	*darkbutton;
  FXButton  	*shinebutton;
  FXButton  	*citrusbutton;
  FXButton  	*orangebutton;
  FXButton  	*noelbutton;
  FXButton  	*pinkbutton;
  FXButton  	*grassbutton;
  FXButton      *waterbutton;
  FXButton  	*skybutton;
  // buttons for themes
  FXButton  	*classicthemebutton;
  FXButton  	*darkthemebutton;
  FXButton  	*shinethemebutton;
  FXButton  	*citrusthemebutton;
  FXButton  	*orangethemebutton;
  FXButton  	*noelthemebutton;
  FXButton  	*pinkthemebutton;
  FXButton  	*grassthemebutton;
  FXButton      *waterthemebutton;
  FXButton  	*skythemebutton;
  // buttons for flags
  FXButton	*en_button;
  FXButton	*it_button;
  FXButton	*de_button;
  FXButton	*fr_button;
  FXButton	*es_button;
  FXButton	*ru_button;
  FXButton	*cn_button;
  FXButton	*jp_button;
  FXButton	*cu_button;
  FXButton	*cu_setting;

  FXButton	*fontbutton;
  FXButton	*fontbutton2;

  FXButton	*mp_button;
  FXButton	*ff_button;
  FXButton	*s1_button;
  FXButton	*s2_button;

  FXIcon	*logoicon;
  FXIcon	*abouticon;
  FXIcon	*conficon;
  FXIcon	*diricon;
  FXIcon 	*fonticon;
  FXIcon 	*execicon;
  FXIcon 	*cancelicon;
  FXIcon 	*accepticon;
  FXIcon 	*ffplayicon;
  FXIcon 	*mplayericon;
  FXIcon 	*sdl1icon;
  FXIcon 	*sdl2icon;

  FXList    	*associationlist;
  FXComboBox 	*mimetypelist;
  FXButton  	*button_bigname;
  FXButton  	*button_smallname;
  FXButton  	*button_restore;
  FXToolTip 	*tooltip;
  FXFont    	*titlefont;
  FXFont    	*bodyfont;
  FXFont    	*menufont;
  FXSpinner	*mousespinner;

  FXColor 	theme_fxmmbase;
  FXColor 	theme_fxmmborder;
  FXColor 	theme_fxmmfore;
  FXColor 	theme_fxmmselfore;
  FXColor 	theme_fxmmmenufore;
  FXColor 	theme_fxmmtipfore;
  FXColor 	theme_fxmmback;
  FXColor 	theme_fxmmselback;
  FXColor 	theme_fxmmmenuback;
  FXColor 	theme_fxmmtipback;
  FXColor 	theme_fxmmhilite;
  FXColor 	theme_fxmmshadow;

  FXString 	quitbuttontext;
  FXString 	openbuttontext;
  FXString 	stopbuttontext;
  FXString 	pausebuttontext;
  FXString 	playbuttontext;
  FXString 	jplaybuttontext;
  FXString 	audiobuttontext1;
  FXString 	audiobuttontext2;
  FXString 	dropbuttontext1;
  FXString 	dropbuttontext2;
  FXString 	loopbuttontext1;
  FXString 	loopbuttontext2;
  FXString 	zoombuttontext1;
  FXString 	zoombuttontext2;
  FXString 	hidebuttontext1;
  FXString 	hidebuttontext2;
  FXString 	outputbuttontext;
  
  FXString 	spebuttontext;
  FXString 	volbuttontext;
  FXString 	bributtontext;
  FXString 	conbuttontext;
  FXString 	huebuttontext;
  FXString 	satbuttontext; 
 
  FXString 	sizebuttontext;
  FXString 	confbuttontext;
  FXString 	upbuttontext;
  FXString 	downbuttontext;
  FXString 	slistbuttontext;
  FXString 	olistbuttontext;
  FXString 	allbuttontext1;
  FXString 	allbuttontext2;
  FXString 	createbuttontext;
  FXString 	recreatebuttontext;
  FXString 	widebuttontext1;
  FXString 	widebuttontext2;
  FXString 	imgbuttontext1;
  FXString 	imgbuttontext2;
  FXString 	deletebuttontext;
  FXString 	clearbuttontext;
  FXString 	increasebuttontext;
  FXString 	decreasebuttontext;
  FXString 	icnlisttext;
  FXString 	detlisttext;

  FXString	file_n;
  FXString	file_t;
  FXString	file_s;
  FXString	file_m;
  FXString	file_u;
  FXString	file_g;
  FXString	file_a;
  FXString	file_l;

  FXString	menu_op;
  FXString	menu_ow;
  FXString	menu_pr;
  FXString	menu_mi;
  FXString	menu_re;
  FXString	menu_mo;
  FXString	menu_sy;
  FXString	menu_cu;
  FXString	menu_co;
  FXString	menu_pa;
  FXString	menu_de;

  FXString	menu_te;
  FXString	menu_he;
  FXString	menu_vi;
  FXString	menu_ar;
  FXString	menu_sr;
  FXString	menu_sh;
  FXString	menu_nd;
  FXString	menu_rd;
  FXString	menu_dd;
  FXString	menu_rf;
  FXString	menu_sc;
  FXString	menu_ma;
  FXString	menu_um;

  FXString	menu_up;
  FXString	menu_do;
  FXString	menu_al;
  FXString	menu_da;
  FXString	menu_ap;
  FXString	menu_in;
  FXString	menu_di;
  FXString	menu_ed;
  FXString	menu_ep;

  FXString	menu_cm;
  FXString	menu_ex;
  FXString	menu_ec;

  FXint	    fxmmwheellines;
  FXbool    automount;
  FXString  defaultplayer;
  FXString  defaultencoder;
  FXString  defaulteditor;
  FXString  defaultpainter;

  FXString  unkextension0;
  FXString  unkextension1;
  FXString  unkextension2;
  FXString  unkextension3;
  FXString  unkextension4;
  FXString  unkextension5;
  FXString  unkextension6;
  FXString  unkextension7;

  FXString  themeicon;
  FXString  theme;
  FXString  language_button;
  FXString  language_menu;
  FXString  language;
  FXString  iconpath;
  FXString  terminal;
  FXString  fontspec;
  FXString  fontspec2;

  FileAssociation   fileassociation;
  FXDataTarget  target_association_type;
  FXDataTarget  target_association_command;
  FXDataTarget  target_association_mimetype;

  FXDataTarget  target_iconpath;
  FXDataTarget  target_terminal;
  FXDataTarget  target_wheel;
  FXDataTarget  target_automount;

  FXDataTarget  target_defaultplayer;
  FXDataTarget  target_defaultencoder;
  FXDataTarget  target_defaulteditor;
  FXDataTarget  target_defaultpainter;

  FXDataTarget  target_unkextension0;
  FXDataTarget  target_unkextension1;
  FXDataTarget  target_unkextension2;
  FXDataTarget  target_unkextension3;
  FXDataTarget  target_unkextension4;
  FXDataTarget  target_unkextension5;
  FXDataTarget  target_unkextension6;
  FXDataTarget  target_unkextension7;

  // ffmpegthumbnailer options
  FXint         thumbnailSize;
  FXint         imageQuality;
  FXbool        filmStripOverlay;
  FXbool        workaroundIssues;
  FXbool        maintainAspectRatio;
  FXbool        smartFrameSelection;
  FXDataTarget 	target_thumbnailSize;
  FXDataTarget  target_imageQuality;
  FXDataTarget  target_filmStripOverlay;
  FXDataTarget  target_workaroundIssues;
  FXDataTarget  target_maintainAspectRatio;
  FXDataTarget  target_smartFrameSelection;

  // thumbnails display options
  FXbool        autoThumbnailShow;
  FXbool        autoThumbnailCreate;
  FXbool        autoThumbnailUpdate;
  FXDataTarget  target_autoThumbnailShow;
  FXDataTarget  target_autoThumbnailCreate;
  FXDataTarget  target_autoThumbnailUpdate;

  // image thumbnail size
  FXint         imagethumbnailSize;
  FXDataTarget 	target_imagethumbnailSize;

private:
  MimeTypeDialog(){};
  MimeTypeDialog(const MimeTypeDialog&){};
  MimeTypeDialog& operator=(const MimeTypeDialog&){};
#ifdef HAVE_LIBFOX_1_7
  void setupIconButton(const FXString& name,FXButton* button);
  FXIcon *createIconFromName(const FXString& name) const;
#endif
  FXbool saveViewerAssociation(FXString viewer, FXString extension);
  void saveFileAssociation();
  void saveThemeIcons();
  void saveThemeColors();
  void readLanguage();
  void saveLanguage();
  //void savePlayer();

public:
  enum {
    ID_CREATE_MIMEASSOCIATION=FXMainWindow::ID_LAST,
    ID_DELETE_MIMEASSOCIATION,
    ID_RENAME_MIMEASSOCIATION,
    ID_SELECT_MIMEASSOCIATION,
    ID_SELECT_ICONPATH,
    ID_SELECT_COMMAND,
    ID_SELECT_MIMETYPE,
    ID_SELECT_ICONBIG_NAME,
    ID_SELECT_ICONSMALL_NAME,
    ID_SELECT_FONT,
    ID_SELECT_FONT2,
    ID_SELECT_TERMINAL,
    ID_SELECT_EDITOR,
    ID_SELECT_PAINTER,

    ID_SELECT_ENCODER_MENCODER,
    ID_SELECT_ENCODER_FFMPEG,

    ID_SELECT_PLAYER_MPLAYER,
    ID_SELECT_PLAYER_FFPLAY,
    ID_SELECT_PLAYER_SDL1,
    ID_SELECT_PLAYER_SDL2,

    ID_SELECT_ICON_DARK,
    ID_SELECT_ICON_SHINE,
    ID_SELECT_ICON_CITRUS,
    ID_SELECT_ICON_ORANGE,
    ID_SELECT_ICON_NOEL,
    ID_SELECT_ICON_PINK,
    ID_SELECT_ICON_GRASS,
    ID_SELECT_ICON_WATER,
    ID_SELECT_ICON_SKY,
    ID_SELECT_ICON_CLASSIC,

    ID_SELECT_THEME_DARK_H,
    ID_SELECT_THEME_DARK_M,
    ID_SELECT_THEME_DARK_L,
    ID_SELECT_THEME_SHINE_H,
    ID_SELECT_THEME_SHINE_M,
    ID_SELECT_THEME_SHINE_L,
    ID_SELECT_THEME_CITRUS_H,
    ID_SELECT_THEME_CITRUS_M,
    ID_SELECT_THEME_CITRUS_L,
    ID_SELECT_THEME_ORANGE_H,
    ID_SELECT_THEME_ORANGE_M,
    ID_SELECT_THEME_ORANGE_L,
    ID_SELECT_THEME_NOEL_H,
    ID_SELECT_THEME_NOEL_M,
    ID_SELECT_THEME_NOEL_L,
    ID_SELECT_THEME_PINK_H,
    ID_SELECT_THEME_PINK_M,
    ID_SELECT_THEME_PINK_L,
    ID_SELECT_THEME_GRASS_H,
    ID_SELECT_THEME_GRASS_M,
    ID_SELECT_THEME_GRASS_L,
    ID_SELECT_THEME_SKY_H,
    ID_SELECT_THEME_SKY_M,
    ID_SELECT_THEME_SKY_L,
    ID_SELECT_THEME_WATER_H,
    ID_SELECT_THEME_WATER_M,
    ID_SELECT_THEME_WATER_L,
    ID_SELECT_THEME_CLASSIC_H,
    ID_SELECT_THEME_CLASSIC_M,
    ID_SELECT_THEME_CLASSIC_L,

    ID_SELECT_LANGUAGE_EN,
    ID_SELECT_LANGUAGE_IT,
    ID_SELECT_LANGUAGE_DE,
    ID_SELECT_LANGUAGE_FR,
    ID_SELECT_LANGUAGE_ES,
    ID_SELECT_LANGUAGE_RU,
    ID_SELECT_LANGUAGE_CN,
    ID_SELECT_LANGUAGE_JP,
    ID_SELECT_LANGUAGE_CU,

    ID_CUSTOM_LANGUAGE,

    ID_RESTORE_SETTINGS,
    ID_FXMMAPPLICATION,
    };

public:
  long onCmdFileAssociation(FXObject*,FXSelector,void*);
  long onCmdCreateFileAssociation(FXObject*,FXSelector,void*);
  long onCmdDeleteFileAssociation(FXObject*,FXSelector,void*);
  long onCmdRenameFileAssociation(FXObject*,FXSelector,void*);

  long onCmdSelectPlayer(FXObject*,FXSelector,void*);
  long onCmdSelectEncoder(FXObject*,FXSelector,void*);
  long onCmdSelectEditor(FXObject*,FXSelector,void*);
  long onCmdSelectPainter(FXObject*,FXSelector,void*);
  long onCmdSelectTerminal(FXObject*,FXSelector,void*);
  long onCmdSelectThemeColors(FXObject*,FXSelector,void*);
  long onCmdSelectThemeIcons(FXObject*,FXSelector,void*);
  long onCmdSelectLanguage(FXObject*,FXSelector,void*);
  long onCmdSelectMimeType(FXObject*,FXSelector,void*);
  long onCmdSelectIconPath(FXObject*,FXSelector,void*);
  long onCmdSelectCommand(FXObject*,FXSelector,void*);
  long onCmdSelectIcon(FXObject*,FXSelector,void*);
  long onCmdSelectFont(FXObject*,FXSelector,void*);
  long onCmdSelectFont2(FXObject*,FXSelector,void*);
  long onCmdCloseDialog(FXObject*,FXSelector,void*);
  long onCmdRestoreDefaults(FXObject*,FXSelector,void*);
  long onCmdCustomLanguage(FXObject*,FXSelector,void*);

public:
  // Constructor
  MimeTypeDialog(FXWindow *owner);
  virtual ~MimeTypeDialog();
  };

#endif
