/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 6.5                   *
*********************************************************************************
* Id: movieinfodialog.cpp,                        2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/

#include <xincs.h>
#include <fx.h>
#include "icons.h"
#include "MovieInfoDialog.h"

#ifdef HAVE_LIBFOX_1_7
 #define VALUE_TO_STRING FXString::value
#elif HAVE_LIBFOX_1_6
 #define VALUE_TO_STRING FXStringVal
#endif

extern "C" {
#ifdef HAVE_LIBAVUTIL
 #include <libavutil/dict.h>
#endif
}

FXIMPLEMENT(MovieInfoDialog,FXDialogBox,NULL,0)

// Create properties dialog
#ifdef HAVE_LIBFOX_1_7
MovieInfoDialog::MovieInfoDialog(FXWindow *own,const FXString& name,FXint w,FXint h):FXDialogBox(own,name,DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,0,0,w+4,0, 4,4,4,4, 4,4){
#elif HAVE_LIBFOX_1_6
MovieInfoDialog::MovieInfoDialog(FXWindow *own,const FXString& name,FXint w,FXint h):FXDialogBox(own,name,DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,0,0,0,0, 4,4,4,4, 4,4){
#endif

  accepticon=new FXGIFIcon(getApp(),m_accept);

  dialogframe=new FXVerticalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_THICK|FRAME_SUNKEN, 0,0,0,0, 0,0,0,0,0,0);

  // Image viewer
  imageframe=new FXImageFrame(dialogframe,NULL,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 0,0,0,0);

  new FXHorizontalSeparator(dialogframe,SEPARATOR_GROOVE|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);

  // text fields
  infoframe=new FXHorizontalFrame(dialogframe,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X,0,0,0,0, 0,0,0,0);

  new FXLabel(infoframe,tr("Name:"),NULL,JUSTIFY_LEFT);
  infolist0=new FXLabel(infoframe,"",0,JUSTIFY_LEFT);
  new FXHorizontalSeparator(dialogframe,SEPARATOR_GROOVE|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);

  matrix=new FXMatrix(dialogframe,3,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_SIDE_BOTTOM,0,0,0,0, 0,0,0,0, 5,0);

  // information
  infolist1_1=new FXLabel(matrix,"",0,JUSTIFY_LEFT);
  infolist2_1=new FXLabel(matrix,"",0,JUSTIFY_LEFT);
  infolist3_1=new FXLabel(matrix,"",0,JUSTIFY_LEFT);

  infolist1_2=new FXLabel(matrix,"",0,JUSTIFY_LEFT);
  infolist2_2=new FXLabel(matrix,"",0,JUSTIFY_LEFT);
  infolist3_2=new FXLabel(matrix,"",0,JUSTIFY_LEFT);

  infolist1_3=new FXLabel(matrix,"",0,JUSTIFY_LEFT);
  infolist2_3=new FXLabel(matrix,"",0,JUSTIFY_LEFT);
  infolist3_3=new FXLabel(matrix,"",0,JUSTIFY_LEFT);

  infolist1_4=new FXLabel(matrix,"",0,JUSTIFY_LEFT);
  infolist2_4=new FXLabel(matrix,"",0,JUSTIFY_LEFT);
  infolist3_4=new FXLabel(matrix,"",0,JUSTIFY_LEFT);

  infolist1_5=new FXLabel(matrix,"",0,JUSTIFY_LEFT);
  infolist2_5=new FXLabel(matrix,"",0,JUSTIFY_LEFT);
  infolist3_5=new FXLabel(matrix,"",0,JUSTIFY_LEFT);

  new FXHorizontalSeparator(dialogframe,SEPARATOR_GROOVE|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);

  infolong1=new FXLabel(dialogframe,"",0,JUSTIFY_LEFT);
  new FXHorizontalSeparator(dialogframe,SEPARATOR_GROOVE|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
  infolong2=new FXLabel(dialogframe,"",0,JUSTIFY_LEFT);
  new FXHorizontalSeparator(dialogframe,SEPARATOR_GROOVE|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
  infolong3=new FXLabel(dialogframe,"",0,JUSTIFY_LEFT);
  new FXHorizontalSeparator(dialogframe,SEPARATOR_GROOVE|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);

  // metadata
  infometadata = new FXLabel(dialogframe,"",0,JUSTIFY_LEFT);
  new FXHorizontalSeparator(dialogframe,SEPARATOR_GROOVE|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);

  // buttons
  buttonsframe=new FXHorizontalFrame(dialogframe,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0, 0,0,0,0);
  new FXButton(buttonsframe,tr(" &CLOSE "),accepticon,this,FXDialogBox::ID_ACCEPT,BUTTON_INITIAL|BUTTON_DEFAULT|BUTTON_NORMAL|LAYOUT_CENTER_X|LAYOUT_CENTER_Y);

  new FXSeparator(dialogframe,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame *copyright=new FXHorizontalFrame(dialogframe,LAYOUT_BOTTOM|LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  FXLabel *label = new FXLabel(copyright,"FXMovieManager - Movie Information",NULL,LAYOUT_FILL_X|LAYOUT_CENTER_Y|JUSTIFY_LEFT,0,0,0,0,15);
  // set the same look of separators
  label->disable();        

  }


FXString MovieInfoDialog::timeConvert(long time) {

    int t_h, t_m, t_s;
    t_h = time/3600;
    t_m = time/60 - t_h*60;
    t_s = time - t_m*60 - t_h*3600;

    timeText=VALUE_TO_STRING(t_h)+"hr:"+VALUE_TO_STRING(t_m)+"min:"+VALUE_TO_STRING(t_s)+"sec ";

  return timeText;
  }


FXString MovieInfoDialog::rateConvert(unsigned int num, unsigned int den) {
  FXfloat val;
  if(den != 0){
    val = FXfloat(num)/FXfloat(den);
  }

  rateText = VALUE_TO_STRING(val,4,2)+" frm/sec ";

  return rateText;
  }

#ifdef HAVE_LIBAVFORMAT
void MovieInfoDialog::processFormat(AVFormatContext *pFormatCtx) {

    const char* fmt;
    FXString format;
    long time;
    int64_t sz;

    // file name
    fmt = pFormatCtx->filename;
    infolist0->setText(fmt);

    // number of streams
    unsigned int strm = pFormatCtx->nb_streams;
    format = "N. "+VALUE_TO_STRING(strm)+" streams ";
    infolist1_1->setText(format.text());

    // file size
    sz = avio_size(pFormatCtx->pb);
    if (sz > 0)
        format = VALUE_TO_STRING(sz)+" kbit ";
    else
        format = "Unknown ";
    infolist1_2->setText(format);

    // format short name
    fmt = pFormatCtx->iformat->name;
    infolist1_3->setText(fmt);

    // bit rate
    time = pFormatCtx->bit_rate/1000;
    if (time > 0)
        infolist1_4->setText((VALUE_TO_STRING(time)+" kbit/sec ").text());
    else
        infolist1_4->setText("Unknown ");

    // time duration
    time = pFormatCtx->duration;
    time /=1000000;
    timeConvert(time);
    infolist1_5->setText(timeText.text());

    // format full name
    fmt = pFormatCtx->iformat->long_name;
    format="Format: "+(FXString)fmt+" ";
    infolong1->setText(format);

  }


void MovieInfoDialog::processVideoStream(AVFormatContext *pFormatCtx, int stream_idx) {

	AVStream *pStream = pFormatCtx->streams[stream_idx];
    AVCodecContext *pCodecCtx;
    AVCodec *pCodec;
	FXString form;
    const char* fmt;
	unsigned int strm = pStream->index;
	unsigned int vnum, vden;

	form = "Stream "+VALUE_TO_STRING(strm);
   	infolist2_1->setText(form.text());

   	infolist2_2->setText("VIDEO ");

    // Get a pointer to the codec context for the video stream
   	if (pCodecCtx = pStream->codec) {
    	// Find the decoder for the stream
    	pCodec=avcodec_find_decoder(pCodecCtx->codec_id);

    	if(pCodec==NULL) {
        	return; // Codec not found
		} else if(avcodec_open2(pCodecCtx, pCodec, NULL) < 0) {
        	return; // Error on opening the Codec
		} else {
			infolist2_3->setText(pCodec->name);

			fmt = pCodec->long_name;
			form="Video: "+(FXString)fmt+" ";
    		infolong2->setText(form);
		}

		if(pStream->avg_frame_rate.num != 0) {
			vnum = pStream->avg_frame_rate.num;
			vden = pStream->avg_frame_rate.den;
			rateConvert(vnum,vden);
			form = rateText;
		} else 
		if(pStream->r_frame_rate.num != 0) {
			vnum = pStream->r_frame_rate.num;
			vden = pStream->r_frame_rate.den;
			rateConvert(vnum,vden);
			form = rateText;
		} else {
			form = "Rate unknown ";
		}
		infolist2_4->setText(form);

		form = VALUE_TO_STRING(pCodecCtx->width) + " x " + VALUE_TO_STRING(pCodecCtx->height)+" ";

		infolist2_5->setText(form);
	} else {
		return;
	}

  }

void MovieInfoDialog::processAudioStream(AVFormatContext *pFormatCtx, int stream_idx) {

	AVStream *pStream = pFormatCtx->streams[stream_idx];
    AVCodecContext *pCodecCtx;
    AVCodec *pCodec;
	FXString form;
    const char* fmt;
	unsigned int strm = pStream->index;

	form = "Stream "+VALUE_TO_STRING(strm);
   	infolist3_1->setText(form.text());
   	infolist3_2->setText("AUDIO ");

    // Get a pointer to the codec context for the audio stream
   	if (pCodecCtx = pStream->codec) {

    	// Find the decoder for the stream
     	pCodec=avcodec_find_decoder(pCodecCtx->codec_id);

    	if(pCodec==NULL) {
        	return; // Codec not found
		} else if(avcodec_open2(pCodecCtx, pCodec, NULL) < 0) {
        	return; // Error on opening the Codec
		} else {
			infolist3_3->setText(pCodec->name);

			fmt = pCodec->long_name;
			form="Audio: "+(FXString)fmt+" ";
    		infolong3->setText(form);
		}

		form = VALUE_TO_STRING(pCodecCtx->sample_rate)+" Hrz ";
       	infolist3_4->setText(form);

		if(pCodecCtx->channels == 1)
			form = "Mono (1) ";
		else 
		if(pCodecCtx->channels == 2)
			form = "Stereo (2) ";
		else 
			form = "N. "+VALUE_TO_STRING(pCodecCtx->channels)+" Channels ";
       	infolist3_5->setText(form);
	} else {
		return;
	}

  }

void MovieInfoDialog::processMetadata(AVFormatContext *pFormatCtx) {
	FXString metadata = "", rowdata = "";
	unsigned int tot = 66;

#ifdef HAVE_LIBAVUTIL
    AVDictionaryEntry *t = NULL;
    while (t = av_dict_get(pFormatCtx->metadata, "", t, AV_DICT_IGNORE_SUFFIX)) {
		rowdata.append(t->key);
		rowdata.append(":");
		rowdata.append(t->value);

		if(metadata.count() + rowdata.count() <= tot) {
			metadata.append(rowdata);
			metadata.append("  ");
		} else {
			metadata.append("\n");
			metadata.append(rowdata);
			tot = tot + 66 - rowdata.count();
		}
		rowdata.clear();
	}
	av_dict_free(&pFormatCtx->metadata);
#endif
	infometadata->setText(metadata);

  }

void MovieInfoDialog::processFileName(const FXString& filename){

    AVFormatContext *pFormatCtx = NULL;
    int i;
    // Register all codecs
    avcodec_register_all();
    // Register all codecs, demux and protocols
    av_register_all();
    // Initialize the network protocol
    avformat_network_init();

    // Open video file
    if(avformat_open_input(&pFormatCtx, filename.text(), NULL, NULL) < 0) {
        fprintf(stderr, "Couldn't open file.\n");
		return; // Couldn't open file
	}

    // process stream information
    if(avformat_find_stream_info(pFormatCtx, NULL) < 0) {
        fprintf(stderr, "Couldn't find stream information.\n");
        return; // Couldn't find stream information
	} else {
    	for (i = 0; i < pFormatCtx->nb_streams; i++) {

	        if(pFormatCtx->streams[i]->codec->codec_type==AVMEDIA_TYPE_VIDEO) {
        		processVideoStream(pFormatCtx, i);
        	}
			else if(pFormatCtx->streams[i]->codec->codec_type==AVMEDIA_TYPE_AUDIO) {
        		processAudioStream(pFormatCtx, i);
        	}
			else {
        		return;
			}
 		}
	}

    // process format information
    processFormat(pFormatCtx);
    // process metadata information
    processMetadata(pFormatCtx);
    // Additionally dump information about file onto standard error
    av_dump_format(pFormatCtx, 0, filename.text(), false);
    // Free context and all its streams 
    avformat_close_input(&pFormatCtx);
    // Deinitialize the network protocol
    avformat_network_deinit();

  }
#endif


void MovieInfoDialog::useCurrentInfo(const FXString& filename, const FXString& grepvideo, const FXString& grepaudio){
    infolist0->setText(filename);
    infolong2->setText("Audio: "+grepaudio);
    infolong3->setText("Video: "+grepvideo);
}


// Destroy
MovieInfoDialog::~MovieInfoDialog(){
  delete imageframe->getImage();
  delete accepticon;

  }

