/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 6.5                   *
*********************************************************************************
* Id: movieinfodialog.h,                          2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/

#ifndef MOVIEINFODIALOG_H
#define MOVIEINFODIALOG_H

#include "config.h"

extern "C" {
#ifdef HAVE_LIBAVFORMAT
 #include <libavformat/avformat.h>
#endif
#ifdef HAVE_LIBAVCODEC
 #include <libavcodec/avcodec.h>
#endif
}

class MovieInfoDialog : public FXDialogBox {
  FXDECLARE(MovieInfoDialog)

protected:
  FXHorizontalFrame *infoframe;
  FXMatrix *matrix;

  FXLabel *infolist0;  // filename
  FXLabel *infolist1_1;
  FXLabel *infolist2_1;
  FXLabel *infolist3_1;
  FXLabel *infolist1_2;
  FXLabel *infolist2_2;
  FXLabel *infolist3_2;
  FXLabel *infolist1_3;
  FXLabel *infolist2_3;
  FXLabel *infolist3_3;
  FXLabel *infolist1_4;
  FXLabel *infolist2_4;
  FXLabel *infolist3_4;
  FXLabel *infolist1_5;
  FXLabel *infolist2_5;
  FXLabel *infolist3_5;
  FXLabel *infolong1;
  FXLabel *infolong2;
  FXLabel *infolong3;
  FXLabel *infometadata;

  FXImageFrame *imageframe;

  FXIcon *accepticon;
  FXVerticalFrame *dialogframe;
  FXHorizontalFrame *buttonsframe;

  FXString timeText;
  FXString rateText;

private:
  MovieInfoDialog(){};
  MovieInfoDialog(const MovieInfoDialog&){};

public:
  MovieInfoDialog(FXWindow *owner,const FXString& name,FXint w, FXint h);

  FXString timeConvert(long time);
  FXString rateConvert(unsigned int num, unsigned int den);
  // find information on file
  void processFileName(const FXString&);
  // or use provided information
  void useCurrentInfo(const FXString&, const FXString&, const FXString&);
#ifdef HAVE_LIBAVFORMAT
  void processFormat(AVFormatContext *pFormatCtx);
  void processMetadata(AVFormatContext *pFormatCtx);
  void processVideoStream(AVFormatContext *pFormatCtx, int stream_idx);
  void processAudioStream(AVFormatContext *pFormatCtx, int stream_idx);
#endif
  // set image name
  void setNewImage(FXImage* img){ imageframe->setImage(img); }
  FXImage* getNewImage() { return imageframe->getImage(); }
  // Destroy
  virtual ~MovieInfoDialog();
  };

#endif  /* MOVIEINFODIALOG_H */
