/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 6.5                   *
*********************************************************************************
* Id: playerdialog.cpp,                           2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/

#include <xincs.h>
#include <fx.h>

#include "config.h"

extern "C" {
#ifdef HAVE_LIBAVFILTER
 #include <libavfilter/avfilter.h>
#endif
}

#include "icons.h"
#include "PlayerDialog.h"
#include "fxplayer_filters.h"

// Message Map for the Scribble Window class
FXDEFMAP(PlayerDialog) PlayerDialogMap[]={

  //________Message_Type_______________________ID___________________Message_Handler_______
  FXMAPFUNC(SEL_COMMAND,	   PlayerDialog::ID_ACCEPT,   PlayerDialog::onCmdAccept),
  FXMAPFUNC(SEL_COMMAND,	   PlayerDialog::ID_CANCEL,   PlayerDialog::onCmdCancel),
  FXMAPFUNCS(SEL_COMMAND,	   PlayerDialog::ID_KEEP_0,   PlayerDialog::ID_KEEP_2,    PlayerDialog::onCmdKeep),
  FXMAPFUNCS(SEL_UPDATE,	   PlayerDialog::ID_KEEP_0,   PlayerDialog::ID_KEEP_2,    PlayerDialog::onUpdKeep),
  FXMAPFUNCS(SEL_COMMAND,	   PlayerDialog::ID_FILTER_0, PlayerDialog::ID_FILTER_7,  PlayerDialog::onCmdFilter),
  FXMAPFUNCS(SEL_UPDATE,	   PlayerDialog::ID_FILTER_0, PlayerDialog::ID_FILTER_7,  PlayerDialog::onUpdFilter),
  FXMAPFUNCS(SEL_COMMAND,	   PlayerDialog::ID_CLOCK_0,  PlayerDialog::ID_CLOCK_2,   PlayerDialog::onCmdClock),
  FXMAPFUNCS(SEL_UPDATE,	   PlayerDialog::ID_CLOCK_0,  PlayerDialog::ID_CLOCK_2,   PlayerDialog::onUpdClock),

  };


FXIMPLEMENT(PlayerDialog,FXDialogBox,PlayerDialogMap,ARRAYNUMBER(PlayerDialogMap))

// the internal SDL1 player
#ifdef ENABLE_PLAYERS 
 #ifdef HAVE_SDL_SDL_H
  extern "C" int loadPlayerFile(char[1024], int64_t, int64_t, int, int, int, int, int, int, int, int, float, int, char[1024], char[1024], char[1024]);
 #endif
 #ifdef HAVE_SDL2_SDL_H
  extern "C" int loadPlayerFile(char[1024], int64_t, int64_t, int, int, int, int, int, int, int, int, float, int, char[1024], char[1024], char[1024]);
 #endif
#endif

char filter[1024];
char plist[1024];
char *acn = NULL;
char *vcn = NULL;
int px, py, pl, pf, pd, pa, pv, pvol;
int64_t pts, ptd;
float pta;

// Create properties dialog
PlayerDialog::PlayerDialog(FXWindow *own):FXDialogBox(own,"Start Player",DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,0,0,0,0, 4,4,4,4, 4,4){
  // icons
  cancelicon=new FXGIFIcon(getApp(),m_cancel);
  accepticon=new FXGIFIcon(getApp(),m_accept);

  // matrix
  FXMatrix *playermatrix=new FXMatrix(this,7,MATRIX_BY_COLUMNS|PACK_UNIFORM_WIDTH|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0, 5,5,5,5);
  // labels
  new FXLabel(playermatrix,tr("Cancel"),NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXLabel(playermatrix,tr("Play"),NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXLabel(playermatrix,tr("List"),NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXLabel(playermatrix,tr("Filter"),NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXLabel(playermatrix,tr("Clock"),NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXLabel(playermatrix,tr("Audio"),NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  new FXLabel(playermatrix,tr("Video"),NULL,LAYOUT_SIDE_TOP|LAYOUT_CENTER_X);
  // dialog buttons
  new FXButton(playermatrix,"&C",cancelicon,this,ID_CANCEL,BUTTON_DEFAULT|BUTTON_NORMAL|LAYOUT_CENTER_X|LAYOUT_CENTER_Y,0,0,0,0,8,8);
  new FXButton(playermatrix,"&P",accepticon,this,ID_ACCEPT,BUTTON_INITIAL|BUTTON_DEFAULT|BUTTON_NORMAL|LAYOUT_CENTER_X|LAYOUT_CENTER_Y);
  // keep going menu
  keepmenu = new FXMenuPane(this);
  keepbutton = new FXMenuButton(playermatrix,"&L _____",NULL,keepmenu,BUTTON_TOOLBAR|MENUBUTTON_DOWN|MENUBUTTON_ATTACH_LEFT|FRAME_RAISED);
#ifdef HAVE_LIBFOX_1_7
  keepbutton->showMenu(false);
#endif
  keep0 = new FXMenuRadio(keepmenu,"One by One",this,ID_KEEP_0);
  keep1 = new FXMenuRadio(keepmenu,"Consecutive",this,ID_KEEP_1);
  keep2 = new FXMenuRadio(keepmenu,"Keep Going",this,ID_KEEP_2); 
  // filter menu
  filtermenu = new FXMenuPane(this);
  filterbutton = new FXMenuButton(playermatrix,"&F _____",NULL,filtermenu,BUTTON_TOOLBAR|MENUBUTTON_DOWN|MENUBUTTON_ATTACH_LEFT|FRAME_RAISED);
#ifdef HAVE_LIBFOX_1_7
  filterbutton->showMenu(false);
#endif
  new FXMenuRadio(filtermenu,"NULL",this,ID_FILTER_0);
  new FXMenuRadio(filtermenu,"H.Inv",this,ID_FILTER_1);
  new FXMenuRadio(filtermenu,"V.Inv",this,ID_FILTER_2); 
  new FXMenuRadio(filtermenu,"Rot.L",this,ID_FILTER_3);
  new FXMenuRadio(filtermenu,"Rot.R",this,ID_FILTER_4); 
  new FXMenuRadio(filtermenu,"Rot.L + H.Inv",this,ID_FILTER_5); 
  new FXMenuRadio(filtermenu,"Rot.R + H.Inv",this,ID_FILTER_6); 
  new FXMenuRadio(filtermenu,"Swap U V",this,ID_FILTER_7); 
  // clock menu
  clockmenu = new FXMenuPane(this);
  clockbutton = new FXMenuButton(playermatrix,"&T _____",NULL,clockmenu,BUTTON_TOOLBAR|MENUBUTTON_DOWN|MENUBUTTON_ATTACH_LEFT|FRAME_RAISED);
#ifdef HAVE_LIBFOX_1_7
  clockbutton->showMenu(false);
#endif
  new FXMenuRadio(clockmenu,"Audio",this,ID_CLOCK_0);
  new FXMenuRadio(clockmenu,"Video",this,ID_CLOCK_1);
  new FXMenuRadio(clockmenu,"Extern",this,ID_CLOCK_2); 
  // user codec
  audio_name = new FXTextField(playermatrix,8,NULL,0,LAYOUT_SIDE_LEFT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_SUNKEN|FRAME_THICK);
  video_name = new FXTextField(playermatrix,8,NULL,0,LAYOUT_SIDE_LEFT|LAYOUT_FILL_X|LAYOUT_CENTER_Y|FRAME_SUNKEN|FRAME_THICK);
  stpncpy(filter, "null", sizeof(filter));
  PlayerDialog::setFocus();

}


void PlayerDialog::returnCodecName(){

  if(comparecase(audio_name->getText(),"") !=0 ){
     acn = (char *)malloc(1024);
     stpncpy(acn, (audio_name->getText()).text(), 1024);
     printf ("requested_audio_codec: %s\n", acn);
  }else{
     free(acn);
     acn = NULL;
  }

  if(comparecase(video_name->getText(),"") !=0 ){
     vcn = (char *)malloc(1024);
     stpncpy(vcn, (video_name->getText()).text(), 1024);
     printf ("requested_video_codec: %s\n", vcn);
  }else{
     free(vcn);
     vcn = NULL;
  }
}

// the call from the GUI
void PlayerDialog::setCmd(char list[1024], int64_t ts, int64_t td, int x, int y, int l, int f, int d, int a, int v, float ta, int vol){ 
  px = x;
  py = y;
  pts = ts;
  ptd = td;
  pl = l;
  pf = f;
  pd = d;
  pa = a;
  pv = v;
  pta = ta;
  pvol = vol;
  stpncpy(plist, list, sizeof(plist));
}

void PlayerDialog::setAccept(){
  returnCodecName();
  getApp()->stopModal(this,true);
  PlayerDialog::hide();
  PlayerDialog::killFocus();
#ifdef ENABLE_PLAYERS
  loadPlayerFile(plist, pts, ptd, px, py, pl, pf, pd, pa, pv, i_clock, pta, pvol, acn, vcn, filter); 
#endif
  return;
}

void PlayerDialog::setKeepGoing(FXint ii_keep){
    //printf ("set ii_keep: %i\n", ii_keep);
    switch(ii_keep){
      case 0:
		i_keep=0;
		keep0->setCheck();
        //printf ("set i_keep: %i\n", i_keep);
		break;
      case 1:
		i_keep=1;
		keep1->setCheck();
        //printf ("set i_keep: %i\n", i_keep);
		break;
      case 2:
		i_keep=2;
		keep2->setCheck();
        //printf ("set i_keep: %i\n", i_keep);
		break;
	}
    return;
}


void PlayerDialog::setFilter(FXint i_filter){
    switch(i_filter){
      case 0:
        stpncpy(filter, "null", sizeof(filter));
		break;
	  case 1:
        stpncpy(filter, "hflip", sizeof(filter));
		break;
	  case 2:
        stpncpy(filter, "vflip", sizeof(filter));
		break;
	  case 3:
        stpncpy(filter, "transpose,hflip", sizeof(filter));
		break;
	  case 4:
        stpncpy(filter, "transpose,vflip", sizeof(filter));
		break;
	  case 5:
        stpncpy(filter, "transpose,hflip,vflip", sizeof(filter));
		break;
	  case 6:
        stpncpy(filter, "transpose", sizeof(filter));
		break;
	  case 7:
        stpncpy(filter, "swapuv", sizeof(filter));
		break;
    }
/* // close the dialog
  returnCodecName();
  getApp()->stopModal(this,true);
  PlayerDialog::hide();
  PlayerDialog::killFocus();
#ifdef ENABLE_PLAYER
  loadPlayerFile(plist, pts, ptd, px, py, pl, pf, pd, pa, pv, i_clock, pta, pvol, acn, vcn, filter); 
#endif
*/
    return;
}

// accept filter
long PlayerDialog::onCmdFilter(FXObject* sender,FXSelector sel,void* ptr){
  FXint n_filter=FXSELID(sel)-ID_FILTER_1+1;
  if(0<=n_filter && n_filter<8){
    switch(FXSELID(sel)){
	  case ID_FILTER_0: i_filter=0; break;
	  case ID_FILTER_1: i_filter=1; break;
	  case ID_FILTER_2: i_filter=2; break;
	  case ID_FILTER_3: i_filter=3; break;
	  case ID_FILTER_4: i_filter=4; break;
	  case ID_FILTER_5: i_filter=5; break;
	  case ID_FILTER_6: i_filter=6; break;
	  case ID_FILTER_7: i_filter=7; break;
    }
  }
  setFilter(i_filter);
  return 1;
  }

// Update
long PlayerDialog::onUpdFilter(FXObject* sender,FXSelector sel,void* ptr){
  FXint n_filter=FXSELID(sel)-ID_FILTER_1+1;
  sender->handle(this,i_filter==n_filter?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
  return 1;
  }

// accept clock
long PlayerDialog::onCmdClock(FXObject* sender,FXSelector sel,void* ptr){
  FXint n_clock=FXSELID(sel)-ID_CLOCK_1+1;
  if(0<=n_clock && n_clock<3){
    switch(FXSELID(sel)){
	  case ID_CLOCK_0: i_clock = 0; break;  // audio
	  case ID_CLOCK_1: i_clock = 1; break;  // video
	  case ID_CLOCK_2: i_clock = 2; break;  // extern
    }
  printf ("requested clock: %i\n", i_clock);
  }

  return 1;
  }

long PlayerDialog::onUpdClock(FXObject* sender,FXSelector sel,void*){
  FXint n_clock=FXSELID(sel)-ID_CLOCK_1+1;
  sender->handle(this,i_clock==n_clock?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);

  return 1;
  }


// accept the playlist mode
long PlayerDialog::onCmdKeep(FXObject* sender,FXSelector sel,void* ptr) {
  FXint n_keep=FXSELID(sel)-ID_KEEP_1+1;
  if(0<=n_keep && n_keep<3){
    switch(FXSELID(sel)){
	  case ID_KEEP_0: i_keep = 0; break;  // play one movie
	  case ID_KEEP_1: i_keep = 1; break;  // play the full list
	  case ID_KEEP_2: i_keep = 2; break;  // set the full list mode forever
    }
  printf ("requested play list mode: %i\n", i_keep);
  }

  return 1;
  }


long PlayerDialog::onUpdKeep(FXObject* sender,FXSelector sel,void*){

  FXint n_keep=FXSELID(sel)-ID_KEEP_1+1;
  sender->handle(this,i_keep==n_keep?FXSEL(SEL_COMMAND,ID_CHECK):FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);

  return 1;
  }


// Close dialog with an accept
long PlayerDialog::onCmdAccept(FXObject*,FXSelector,void*){
  //stpncpy(filter, "null", sizeof(filter));
  //i_filter = 0;
/*
  returnCodecName();
  getApp()->stopModal(this,true);
  PlayerDialog::hide();
  PlayerDialog::killFocus();
#ifdef ENABLE_PLAYERS
  loadPlayerFile(plist, pts, ptd, px, py, pl, pf, pd, pa, pv, i_clock, pta, pvol, acn, vcn, filter); 
#endif
*/
  setAccept();
  return 1;
  }

// Close dialog with a cancel
long PlayerDialog::onCmdCancel(FXObject*,FXSelector,void*){
  getApp()->stopModal(this,false);
  PlayerDialog::hide();
  PlayerDialog::killFocus();
  return 1;
  }


// Destroy
PlayerDialog::~PlayerDialog(){

  delete cancelicon;
  delete accepticon;

#ifdef HAVE_LIBAVFILTER
  if(vfilters){
    fprintf(stderr, "dialog: freeing video filters: %i and audio filters: %i\n", vfilters, afilters);
    vfilters = NULL;
    afilters = NULL;
    av_freep(&vfilters);
    av_freep(&afilters);
  }
#endif

  }



