/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008,2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                            version 6.5                   *
*********************************************************************************
* Id: propertiesdialog_lp.cpp,                    2008/01/01                    *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/
#include <xincs.h>
#include <fx.h>
#include "PropertiesDialog.h"
#include "fxmoviemanager.h"
#include "icons.h"


FXIMPLEMENT(PropertiesDialog_lp,FXDialogBox,NULL,0)


// Create properties dialog
PropertiesDialog_lp::PropertiesDialog_lp(FXWindow *own):FXDialogBox(own,"Left File List",DECOR_TITLE|DECOR_BORDER|DECOR_RESIZE,0,0,660,480, 4,4,4,4, 4,4){

  accepticon=new FXGIFIcon(getApp(),m_accept);
  abouticon=new FXGIFIcon(getApp(),b_list);

  // Buttons
  FXHorizontalFrame *closebox=new FXHorizontalFrame(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH);
  new FXButton(closebox,tr("&CLOSE"),accepticon,this,FXDialogBox::ID_ACCEPT,BUTTON_DEFAULT|ICON_BEFORE_TEXT|LAYOUT_RIGHT|FRAME_RAISED|FRAME_THICK,0,0,0,0, 20,20,5,5);

  // Separator
  new FXHorizontalSeparator(this,SEPARATOR_GROOVE|LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);

  // reused frame
  FXVerticalFrame   *vframe=NULL;
  // main frames
  FXVerticalFrame *generalFrame=new FXVerticalFrame(this,LAYOUT_FILL_X|LAYOUT_FILL_Y|FRAME_RAISED|FRAME_THICK);
  FXHorizontalFrame *hmainframe=new FXHorizontalFrame(generalFrame,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);
  FXVerticalFrame *buttonframe=new FXVerticalFrame(hmainframe,LAYOUT_FILL_Y|LAYOUT_LEFT|PACK_UNIFORM_WIDTH|PACK_UNIFORM_HEIGHT,0,0,0,0, 5,5,5,5);

  FXSwitcher *switcher = new FXSwitcher(hmainframe,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0);

  vframe = new FXVerticalFrame(buttonframe,FRAME_SUNKEN,0,0,0,0,0,0,0,0);
  new FXButton(vframe,"Information",abouticon,switcher,FXSwitcher::ID_OPEN_FIRST,FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL);
  vframe = new FXVerticalFrame(buttonframe,FRAME_SUNKEN,0,0,0,0,0,0,0,0);
  new FXButton(vframe,"Permissions",abouticon,switcher,FXSwitcher::ID_OPEN_SECOND,FRAME_RAISED|ICON_ABOVE_TEXT|LAYOUT_FILL);


  // **************************information*************************
  vframe = new FXVerticalFrame(switcher,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);

  FXGroupBox *namegroup=new FXGroupBox(vframe,tr("Description"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
  filename=new FXLabel(namegroup,FXString::null,NULL,LAYOUT_CENTER_Y|LAYOUT_SIDE_LEFT|ICON_BEFORE_TEXT|LAYOUT_FIX_HEIGHT,0,0,0,40);
  filename->setTarget(own);
  filename->setSelector(FXMovieManager::ID_FILE_DESC_LP);


  FXGroupBox *attrgroup=new FXGroupBox(vframe,tr("General Info"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
  FXMatrix *attrmatrix=new FXMatrix(attrgroup,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y);
  new FXLabel(attrmatrix,tr("Type:"),NULL,LAYOUT_RIGHT);
  filetype=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  filetype->setTarget(own);
  filetype->setSelector(FXMovieManager::ID_FILE_TYPE_LP);
  new FXLabel(attrmatrix,tr("MimeType:"),NULL,LAYOUT_RIGHT);
  filemimetype=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  filemimetype->setTarget(own);
  filemimetype->setSelector(FXMovieManager::ID_FILE_MIMETYPE_LP);
  new FXLabel(attrmatrix,tr("Command:"),NULL,LAYOUT_RIGHT);
  filecommand=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  filecommand->setTarget(own);
  filecommand->setSelector(FXMovieManager::ID_FILE_COMMAND_LP);
  new FXLabel(attrmatrix,tr("Location:"),NULL,LAYOUT_RIGHT);
  directory=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  directory->setTarget(own);
  directory->setSelector(FXMovieManager::ID_FILE_LOCATION_LP);
  new FXLabel(attrmatrix,tr("Size:"),NULL,LAYOUT_RIGHT);
  filesize=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  filesize->setTarget(own);
  filesize->setSelector(FXMovieManager::ID_FILE_SIZE_LP);
  new FXLabel(attrmatrix,tr("Video:"),NULL,LAYOUT_RIGHT);
  videoaspect=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  videoaspect->setTarget(own);
  videoaspect->setSelector(FXMovieManager::ID_VIDEO_ASPECT_LP);
  new FXLabel(attrmatrix,tr("Audio:"),NULL,LAYOUT_RIGHT);
  audioformat=new FXLabel(attrmatrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  audioformat->setTarget(own);
  audioformat->setSelector(FXMovieManager::ID_AUDIO_FORMAT_LP);


  FXGroupBox *timegroup=new FXGroupBox(vframe,tr("File Times"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
  FXMatrix *timematrix=new FXMatrix(timegroup,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y);
  new FXLabel(timematrix,tr("Created:"),NULL,LAYOUT_RIGHT);
  createtime=new FXLabel(timematrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  createtime->setTarget(own);
  createtime->setSelector(FXMovieManager::ID_FILE_CREATED_LP);
  new FXLabel(timematrix,tr("Modified:"),NULL,LAYOUT_RIGHT);
  modifytime=new FXLabel(timematrix,FXString::null,NULL,LAYOUT_LEFT|LAYOUT_FILL_COLUMN);
  modifytime->setTarget(own);
  modifytime->setSelector(FXMovieManager::ID_FILE_MODIFIED_LP);


  // ******************************permissions**************************
  vframe = new FXVerticalFrame(switcher,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0,0,0);

  FXGroupBox *ownergroup=new FXGroupBox(vframe,tr("Ownership"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
  FXMatrix *ownermatrix=new FXMatrix(ownergroup,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y);

  fileowner=new FXTextField(ownermatrix,28,own,FXMovieManager::ID_OWNER_LP,TEXTFIELD_READONLY,LAYOUT_FILL_X|LAYOUT_CENTER_Y|LAYOUT_FILL_COLUMN|FRAME_SUNKEN|FRAME_THICK);
  new FXLabel(ownermatrix,tr("Owner"),NULL,LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_COLUMN);

  filegroup=new FXTextField(ownermatrix,28,own,FXMovieManager::ID_GROUP_LP,TEXTFIELD_READONLY,LAYOUT_FILL_X|LAYOUT_CENTER_Y|LAYOUT_FILL_COLUMN|FRAME_SUNKEN|FRAME_THICK);
  new FXLabel(ownermatrix,tr("Group"),NULL,LAYOUT_LEFT|LAYOUT_CENTER_Y|LAYOUT_FILL_COLUMN);


  FXGroupBox *permissiongroup=new FXGroupBox(vframe,tr("Permissions"),GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X);
  FXMatrix *permissionmatrix=new FXMatrix(permissiongroup,5,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y);

  FXGroupBox *group1=new FXGroupBox(permissionmatrix,tr("Owner"),GROUPBOX_TITLE_CENTER|FRAME_RIDGE);
  new FXCheckButton(group1,"Read",own,FXMovieManager::ID_READOWNER_LP);
  new FXCheckButton(group1,"Write",own,FXMovieManager::ID_WRITEOWNER_LP);
  new FXCheckButton(group1,"Execute",own,FXMovieManager::ID_EXECUTEOWNER_LP);

  FXGroupBox *group2=new FXGroupBox(permissionmatrix,tr("Group"),GROUPBOX_TITLE_CENTER|FRAME_RIDGE);
  new FXCheckButton(group2,"Read",own,FXMovieManager::ID_READGROUP_LP);
  new FXCheckButton(group2,"Write",own,FXMovieManager::ID_WRITEGROUP_LP);
  new FXCheckButton(group2,"Execute",own,FXMovieManager::ID_EXECUTEGROUP_LP);

  FXGroupBox *group3=new FXGroupBox(permissionmatrix,tr("Other Users"),GROUPBOX_TITLE_CENTER|FRAME_RIDGE);
  new FXCheckButton(group3,"Read",own,FXMovieManager::ID_READOTHER_LP);
  new FXCheckButton(group3,"Write",own,FXMovieManager::ID_WRITEOTHER_LP);
  new FXCheckButton(group3,"Execute",own,FXMovieManager::ID_EXECUTEOTHER_LP);

//  new FXFrame(permissionmatrix,LAYOUT_FILL_COLUMN);

//  FXGroupBox *group4=new FXGroupBox(permissionmatrix,tr("Special"),GROUPBOX_TITLE_CENTER|FRAME_RIDGE);
//  new FXCheckButton(group4,"Set UserID",own,FXMovieManager::ID_SETUID_LP);
//  new FXCheckButton(group4,"Set GroupID",own,FXMovieManager::ID_SETGID_LP);
//  new FXCheckButton(group4,"Set Sticky",own,FXMovieManager::ID_STICKY_LP);


  new FXSeparator(generalFrame,SEPARATOR_GROOVE|LAYOUT_FILL_X);
  FXHorizontalFrame *copyright=new FXHorizontalFrame(generalFrame,LAYOUT_BOTTOM|LAYOUT_FILL_X,0,0,0,0,5,5,5,5);
  FXLabel *label = new FXLabel(copyright,"FXMovieManager - Movie Properties",NULL,LAYOUT_FILL_X|LAYOUT_CENTER_Y|JUSTIFY_LEFT,0,0,0,0,15);
  // set the same look of separators
  label->disable();

  }

// Destroy
PropertiesDialog_lp::~PropertiesDialog_lp(){
  delete accepticon;
  delete abouticon;
  }
