/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008-2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                               version 6.5                *
*********************************************************************************
* Id: fxmoviemanager.h,                              2008/01/01                 *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/
#ifndef FXMOVIEMANAGER_H
#define FXMOVIEMANAGER_H

#include "config.h"

//! forward declarations for persistent classes
class PropertiesDialog_lp;
class PropertiesDialog_rp;
class MimeTypeDialog;
class DiskMapDialog;
class FileSearchDialog;
class FileInputDialog;
class PlayerDialog;

//! classes created on demand and then destroyed
class OperationsDialog;
class MovieInfoDialog;

class FXMovieManager : public FXMainWindow {
    FXDECLARE(FXMovieManager)

private:
    FXMovieManager(){};
    FXMovieManager(const FXMovieManager&){};

protected:
	//! declared dialogs for persistent classes
	PropertiesDialog_lp *properties_lp;
	PropertiesDialog_rp *properties_rp;
	MimeTypeDialog 	*mimetype;
	DiskMapDialog *diskmapdialog;
	FileSearchDialog *filesearchdialog;
	FileInputDialog *inputdialog;
	PlayerDialog *playerdialog;

	//! drag types
	FXDragType  urilistType;    // FXMM drag list type
	FXDragType  actionType;     // FXMM drag action type

	FXString	clipboard;  // our CLIPBOARD

	//! logo
	FXIcon		*logoicon;
	FXIcon		*logomedicon;
	FXIcon		*logominiicon;
	FXIcon		*splashicon;
	//! themes buttons
	FXIcon		*audioicon;
	FXIcon		*createicon; 
	FXIcon		*decreaseicon; 
	FXIcon		*deleteicon; 
	FXIcon		*deletehiddenicon; 
	FXIcon		*downicon;
	FXIcon		*dropicon; 
	FXIcon		*hiddenicon;
	FXIcon		*hideicon; 
	FXIcon		*increaseicon; 
	FXIcon		*loopicon;
	FXIcon		*openicon; 
	FXIcon		*saveicon; 
	FXIcon		*pauseicon;
	FXIcon		*playicon;
	FXIcon		*quiticon;
	FXIcon     	*recreateicon; 
	FXIcon     	*showicon; 
	FXIcon     	*stopicon;
	FXIcon		*upicon;
	FXIcon     	*videoouticon;
	FXIcon     	*videosizeicon;
	FXIcon     	*videozoomicon;
	FXIcon     	*videoicon;
	FXIcon		*detlisticon;
	FXIcon     	*icnlisticon;
	FXIcon		*imgpreview1icon;
	FXIcon     	*imgpreview2icon;
	//! menus buttons
	FXIcon	   	*m_bugicon;
	FXIcon	   	*m_upicon;
	FXIcon	   	*m_downicon;
	FXIcon	   	*m_appendicon;
	FXIcon	   	*m_appendicon2;
	FXIcon	   	*m_inserticon;
	FXIcon	   	*m_inserticon2;
	FXIcon	   	*m_editicon;
	FXIcon	   	*m_exporticon;
	FXIcon	   	*m_accepticon;
	FXIcon	   	*m_cancelicon;
	FXIcon	   	*m_propicon;
	FXIcon	   	*m_infoicon;
	FXIcon	   	*m_renameicon;
	FXIcon 		*m_cuticon;
	FXIcon 		*m_copyicon;
	FXIcon 		*m_pasteicon;
	FXIcon	   	*m_moveicon;
	FXIcon	   	*m_linkicon;
	FXIcon	   	*m_consoleicon;
	FXIcon	   	*m_terminalicon;
	FXIcon	   	*m_archiveicon;
	FXIcon	   	*m_searchicon;
	FXIcon	   	*m_connecticon;
	FXIcon	   	*m_mapicon;
	FXIcon	   	*m_unmapicon;
	FXIcon	   	*m_deleteicon;
	FXIcon	   	*m_refreshicon;
	FXIcon	   	*m_renamediricon;
	FXIcon	   	*m_showhiddenicon;
	//! virtual icon
	FXIcon 		*deviceicon;
	//! devices
	FXIcon 		*m_removableicon;
	FXIcon 		*m_harddiskicon;
	FXIcon 		*m_isodiskicon;
	FXIcon 		*m_floppydiskicon;
	//! filelist headers
	FXIcon		*m_usricon;
	FXIcon		*m_grpicon;
	FXIcon		*m_prmicon;
	FXIcon		*m_dimicon;
	FXIcon		*m_daticon;
	FXIcon		*m_diricon;

  	FXTabBook*  leftpanel_tabbook;
  	FXTabItem*  tab_dirlist_lp;
  	FXTabItem*  tab_filelist_lp;
  	FXTabItem*  tab_fulllist_lp;

  	FXTabBook*  rightpanel_tabbook;
  	FXTabItem*  tab_dirlist_rp;
  	FXTabItem*  tab_filelist_rp;
  	FXTabItem*  tab_fulllist_rp;

	//! Menus
	FXMenuBar 	*topmenubar;
   	FXMenuPane 	*menu_file; 
    FXMenuTitle *title_file;
    FXMenuCommand *cmd_quit;
    FXMenuCommand *cmd_openl;
    FXMenuCommand *cmd_openr;

   	FXMenuPane 	*menu_options; 
    FXMenuTitle *title_options;
    FXMenuCommand *cmd_audio;
    FXMenuCommand *cmd_drop;
    FXMenuCommand *cmd_loop;
    FXMenuCommand *cmd_zoom;
    FXMenuCommand *cmd_hide;

   	FXMenuPane 	*menu_player; 
    FXMenuTitle *title_player;
    FXMenuCommand *cmd_stop;
    FXMenuCommand *cmd_pause;
    FXMenuCommand *cmd_play;

   	FXMenuPane 	*menu_wide; 
    FXMenuTitle *title_wide;

   	FXMenuPane 	*menu_extent; 
    FXMenuTitle *title_extent;

   	FXMenuPane 	*menu_video; 
    FXMenuTitle *title_video;

   	FXMenuPane 	*menu_table; 
    FXMenuTitle *title_table;

	FXMenuBar 	*menubar;           
	FXMenuPane 	*popupmenu;         
	FXMenuPane 	*videosizemenu1;
	FXMenuPane 	*videosizemenu2;
	FXMenuPane 	*videooutmenu;
	FXMenuPane 	*archivemenu;
	FXMenuPane 	*compressmenu;

    FXMenuRadio *menu_vs01;
    FXMenuRadio *menu_vs02;
    FXMenuRadio *menu_vs03;
    FXMenuRadio *menu_vs04;
    FXMenuRadio *menu_vs05;
    FXMenuRadio *menu_vs06;
    FXMenuRadio *menu_vs07;
    FXMenuRadio *menu_vs08;
    FXMenuRadio *menu_vs09;
    FXMenuRadio *menu_vs10;
    FXMenuRadio *menu_vs11;
    FXMenuRadio *menu_vs12;
    FXMenuRadio *menu_vs13;
    FXMenuRadio *menu_vs14;
    FXMenuRadio *menu_vs15;
    FXMenuRadio *menu_vs16;
    FXMenuRadio *menu_vs17;
    FXMenuRadio *menu_vs18;
    FXMenuRadio *menu_vs19;
    FXMenuRadio *menu_vs20;
    FXMenuRadio *menu_vs21;
    FXMenuRadio *menu_vs22;
    FXMenuRadio *menu_vs23;
    FXMenuRadio *menu_vs24;
    FXMenuRadio *menu_vs25;
    FXMenuRadio *menu_vs26;

    FXMenuRadio *menu_vo01;
    FXMenuRadio *menu_vo02;
    FXMenuRadio *menu_vo03;
    FXMenuRadio *menu_vo04;
    FXMenuRadio *menu_vo05;
    FXMenuRadio *menu_vo06;
    FXMenuRadio *menu_vo07;
    FXMenuRadio *menu_vo08;
    FXMenuRadio *menu_vo09;
    FXMenuRadio *menu_vo10;

    FXMenuCommand *pop_up;
    FXMenuCommand *pop_do;
    FXMenuCommand *pop_al;
    FXMenuCommand *pop_da;
    FXMenuCommand *pop_ap_lp;
    FXMenuCommand *pop_ap_rp;
    FXMenuCommand *pop_in_lp;
    FXMenuCommand *pop_in_rp;
    FXMenuCommand *pop_di;
    FXMenuCommand *pop_ed;
    FXMenuCommand *pop_ep;

	FXLabel 	*playlistlabel;

	FXSplitter 	*splitter1;
	FXSplitter 	*splitter2;
	FXSplitter 	*splitter_rp;
	FXSplitter 	*splitter_lp;

	FXVerticalFrame   *toplistframe;
	FXHorizontalFrame *listframe;   // the list frame	
	FXHorizontalFrame *optionsframe;
	FXTable			  *table;	
	FXVerticalFrame   *listbuttonframe;

	FXHorizontalFrame *filesbuttonframe_lp;
	FXVerticalFrame   *filesframe_lp;
	FXVerticalFrame   *vbuttonframe_lp;
	FXHorizontalFrame *panelframe_lp;
	FXToolBar         *paneltoolbar_lp;

	FXHorizontalFrame *filesbuttonframe_rp;
	FXVerticalFrame   *filesframe_rp;
	FXVerticalFrame   *vbuttonframe_rp;
	FXHorizontalFrame *panelframe_rp;
	FXToolBar         *paneltoolbar_rp;

	FXHorizontalFrame *sizeframe;
	FXHorizontalFrame *switchframe;
	FXHorizontalFrame *progressframe;

	FXHorizontalFrame *statusbar;
	FXStatusLine 	  *statusline;

	FXKnob 	*spe_knob;
	FXKnob 	*vol_knob;

	FXRealSpinner 	*delayspinner;

	FXKnob 	*bri_knob;
	FXKnob 	*con_knob;
	FXKnob 	*gam_knob;
	FXKnob 	*hue_knob;
	FXKnob 	*sat_knob;

	FXRealSpinner 	*seekspinner;
	FXRealSpinner 	*relatspinner;

    FXDirList  	*dirlist_lp;
    FXDirList  	*dirlist_rp;
    FXFileList 	*filelist_lp;
    FXFileList 	*filelist_rp;
    FXFileList 	*panel;

#ifdef HAVE_LIBFOX_1_7
    FXFileAssociations *associations;  // File associations
#elif HAVE_LIBFOX_1_6
    FXFileDict *associations;
#endif

	FXTextField 	*seekposition1;
	FXTextField 	*seekposition2;
	FXTextField 	*seekposition3;
	FXTextField 	*seekposition4;
	FXTextField 	*endposition1;
	FXTextField 	*endposition2;
	FXTextField 	*endposition3;
	FXTextField 	*endposition4;

	FXTextField 	*clock;

	FXProgressBar 	*progressbar;

	FXButton 	*quitbutton;
	FXButton 	*openbutton;
	FXButton 	*playbutton;
	FXButton 	*pausebutton;
	FXButton 	*stopbutton;

	FXToggleButton 	*dropbutton;
	FXToggleButton 	*audiobutton;
	FXToggleButton 	*loopbutton;
	FXToggleButton 	*zoombutton;
	FXToggleButton 	*hidebutton;
	FXToggleButton 	*selectbutton;
	FXToggleButton 	*widebutton;
	FXMenuButton 	*videosizebutton1;
	FXMenuButton 	*videosizebutton2;
	FXMenuButton 	*videooutbutton;

	FXFont      *bodyfont;
	FXFont      *menufont;
	FXToolTip	*tooltip;
protected:
    FXString      currentTemp;
    FXString      currentUser;

    FXColor 	theme_fxmmbase;
    FXColor 	theme_fxmmborder;
    FXColor 	theme_fxmmfore;
    FXColor 	theme_fxmmselfore;
    FXColor 	theme_fxmmmenufore;
    FXColor 	theme_fxmmtipfore;
    FXColor 	theme_fxmmback;
    FXColor 	theme_fxmmselback;
    FXColor 	theme_fxmmmenuback;
    FXColor 	theme_fxmmtipback;
    FXColor 	theme_fxmmhilite;
    FXColor 	theme_fxmmshadow;

    FXString 	cursearchdir;

    FXString 	defaultplayer;

    FXString 	themeicon;
    FXString 	theme;
    FXString 	currentdir_lp; 
    FXString 	currentdir_rp;
    FXString 	filename;
    FXString 	language;
    FXString 	terminal;

    FXString 	fontspec;
    FXString 	fontspec2;

    FXString	unkextension0;
    FXString	unkextension1;
    FXString	unkextension2;
    FXString	unkextension3;
    FXString	unkextension4;
    FXString	unkextension5;
    FXString	unkextension6;
    FXString	unkextension7;

    FXString 	s_play;
    FXString 	s_command;
    FXString 	s_video;
    FXString 	s_size;
    FXString 	s_full;
    FXString 	s_loop;
    FXString 	s_audio;
    FXString 	s_frame;
    FXString 	s_xsize;
    FXString 	s_ysize;
    FXString 	s_list;

    FXString    j1_command;
    FXString    j3_command;
    FXString    j5_command;

	FXString 	currentInfo_lp;
	FXString 	currentInfo_rp;
	FXString 	currentFifo;
	FXString 	removeTempFifo;
	FXString 	createTempFifo;

	FXString 	grepvideo_lp;
	FXString 	grepaudio_lp;
	FXString 	grepvideo_rp;
	FXString 	grepaudio_rp;

	FXString 	quitbuttontext;
	FXString 	openbuttontext;
	FXString 	stopbuttontext;
	FXString 	pausebuttontext;
	FXString 	playbuttontext;
	FXString 	jplaybuttontext;
	FXString 	audiobuttontext1;
	FXString 	audiobuttontext2;
	FXString 	dropbuttontext1;
	FXString 	dropbuttontext2;
	FXString 	loopbuttontext1;
	FXString 	loopbuttontext2;
	FXString 	zoombuttontext1;
	FXString 	zoombuttontext2;
	FXString 	hidebuttontext1;
	FXString 	hidebuttontext2;
	FXString 	outputbuttontext;
	FXString 	sizebuttontext;
	FXString 	confbuttontext;
	FXString 	upbuttontext;
	FXString 	downbuttontext;
	FXString 	slistbuttontext;
	FXString 	olistbuttontext;
  	FXString 	allbuttontext1;
	FXString 	allbuttontext2;
	FXString 	createbuttontext;
	FXString 	recreatebuttontext;
  	FXString 	widebuttontext1;
	FXString 	widebuttontext2;
  	FXString 	imgbuttontext1;
	FXString 	imgbuttontext2;
	FXString 	deletebuttontext;
	FXString 	clearbuttontext;
	FXString 	increasebuttontext;
	FXString 	decreasebuttontext;
	FXString 	icnlisttext;
	FXString 	detlisttext;
	FXString 	spebuttontext;
	FXString 	volbuttontext;
	FXString 	bributtontext;
	FXString 	conbuttontext;
	FXString 	huebuttontext;
	FXString 	satbuttontext; 

    FXString	file_n;
    FXString	file_t;
    FXString	file_s;
    FXString	file_m;
    FXString	file_u;
    FXString	file_g;
    FXString	file_a;
    FXString	file_l;

    FXString	menu_op;
    FXString	menu_ow;
    FXString	menu_pr;
    FXString	menu_mi;
    FXString	menu_re;
    FXString	menu_mo;
    FXString	menu_sy;
    FXString	menu_cu;
    FXString	menu_co;
    FXString	menu_pa;
    FXString	menu_de;

    FXString	menu_te;
    FXString	menu_he;
    FXString	menu_vi;
    FXString	menu_ar;
    FXString	menu_sr;
    FXString	menu_sh;
    FXString	menu_nd;
    FXString	menu_rd;
    FXString	menu_dd;
    FXString	menu_rf;
    FXString	menu_sc;
    FXString	menu_ma;
    FXString	menu_um;

    FXString	menu_up;
    FXString	menu_do;
    FXString	menu_al;
    FXString	menu_da;
    FXString	menu_ap;
    FXString	menu_in;
    FXString	menu_di;
    FXString	menu_ed;
    FXString	menu_ep;

	FXString	map_cmd;
	FXString 	map_label;

	//! current searched file
	FXString	searchfile;

	//! ffplay options only
	FXString 	f_audio;

	//! fxplayer options only
	int 		size_x;
	int 		size_y;
	int 		loop;
	int 		full;
	int 		drop;
	int 		disable_audio;
	int 		disable_video;
	float		time_a;
	int 		i_volume;
    FXint       i_keep;

	//! all other options
	FXint 		i_video;
	FXint 		i_size;
	FXint 		imgw;
	FXint 		imgh;
	FXint 		dlgw;
	FXint 		dlgh;
	FXint 		numtableitems;
	FXint		fxmmwheellines;

	FXbool		automount;
	FXbool 		listshow;
	FXbool 		isrunning;
	FXbool		widescreen;

  	//! ffmpegthumbnailer options
  	FXint     thumbnailSize;
  	FXint     imageQuality;
  	FXbool    filmStripOverlay;
  	FXbool    workaroundIssues;
  	FXbool    maintainAspectRatio;
  	FXbool    smartFrameSelection;

	FXbool	  autoThumbnailShow;
	FXbool	  autoThumbnailCreate;
	FXbool	  autoThumbnailUpdate;

	//! image preview size
	FXint     imagethumbnailSize;

protected:
	FXint getTableNums() const;
	FXString returnPlaylist();

	FXbool saveExportCommand(FXString& exportcommand, const FXString& filename);
	FXbool savePlaylistTable(const FXString& filename);
	FXbool loadPlaylistTable(const FXString& filename);
	FXbool previewListMovie(const FXString& filename, FXint i);
	FXbool previewMovie(FXFileList* panel, const FXString& filename, FXint i, FXint w, FXint h);
	FXbool createImageMovie(const FXString& filetoplay, const FXString& rootname);
	FXbool createInfoMovie(const FXString& filename, const FXString& currentInfo);
	FXbool freeImageMemory(FXFileList* panel, FXint i);
	FXbool executeMapping(FXFileList* panel, const FXString& map_cmd, const FXString& map_label);
	FXbool compareDevice(const FXString& devname);
	FXbool cmdFileSearch(FXFileList* panel);
	FXbool loadfilevideo(const FXString& filename);
	FXbool loadfileaudio(const FXString& filename);
	FXbool loadfileimage(const FXString& filename);
	FXbool readPreConfig();
	FXbool readConfig();
	FXbool themeSelection();
	FXbool languageSelection();

	void showFilelistThumbnails_lp();
	void showFilelistThumbnails_rp();
	void showThumbnails(FXFileList* panel);
	void cmdFilePreview(FXFileList* panel);
	void cmdForceFilePreview(FXFileList* panel);
	void cmdIncFilePreview(FXFileList* panel);
	void cmdDecFilePreview(FXFileList* panel);
	void cmdClearPreview(FXFileList* panel);

	void getFilelistSelection_lp();
	void getFilelistSelection_rp();
	void appendFiledialogSelection(const FXString& currentdir);
	void insertFiledialogSelection(const FXString& currentdir);
	void resetTable();
	void selectAll();

	void setIconDark();
	void setIconShine();
	void setIconCitrus();
	void setIconOrange();
	void setIconNoel();
	void setIconPink();
	void setIconGrass();
	void setIconWater();
	void setIconSky();
	void setIconClassic();

	void quitAppFxmm();

	void cmdFileDelete(FXFileList* panel);
	void cmdFileSymlink(FXFileList* panel, FXFileList* out_panel);
	void cmdFileCopy(FXFileList* panel, FXFileList* out_panel);
	void cmdFileRename(FXFileList* panel, FXFileList* out_panel);
	FXString oldImageOperation(FXString& filename, FXString& imagename, FXFileList* panel);
	void newImageOperation(FXString& imagename, OperationsDialog* operationsdialog);
	void newImageInfo(FXString& imagename, MovieInfoDialog* infodialog);

	long cmdCopyCut(FXFileList* panel, FXSelector sel);
	long cmdPaste(FXFileList* panel, FXSelector sel);

	void cmdImagePlay(FXFileList* panel);
	void cmdFilePlay(FXFileList* panel);
	void cmdFilePause();
	void cmdFileStop();

	void cmdRunCommand(FXFileList* filepanel);
	void cmdOpen(FXFileList* filepanel, FXDirList* dirpanel);
	void cmdOpenWith(FXFileList* filepanel);
	void cmdScanVirus(FXString& currentdir);
	void cmdArchive(FXString& currentdir);

	FXlong getSizeFilenames(FXFileList* panel) const;
	FXint getNumFilenames(FXFileList* panel) const;
	FXString* getFilenames(FXFileList* panel) const;
	FXString getDirectory(FXFileList* panel) const;
	void deselectMainDir(FXFileList* panel);
	void cmdProperties(FXFileList* panel, const FXString& currentInfo, FXString& grepvideo, FXString& grepaudio);
	void cmdMovieInfo(FXFileList* panel, MovieInfoDialog* info, FXbool rflag);
	void synchronize_lp(FXString& synchdir);
	void synchronize_rp(FXString& synchdir);
	void recursiveScan(const FXString& filetoscan, const FXString& dirname, FXuint opt);
	FXbool matchFileContainingName(const FXString& filename, const FXString& name, FXuint opt);
	void updMapReport(const FXString& devname, FXIcon* devicon);
	void updFileReport(const FXString& filename, FXIcon* fileicon);
	void prnReport(FXFileList* panel);
	void setVideoSize(FXint i_size);
	void setVideoOut(FXint i_video);
	void updateMappedDevices(FXFileList* filelist, FXbool askdialog);
	void updateMappedDevices1(FXFileList* filelist, FXbool askdialog);
	void updateMappedDevices2(FXFileList* filelist, FXbool askdialog);
	void updateMappedDevices3(FXFileList *filelist, FXString& user, FXString& temp);

public:
	FXMovieManager(FXApp *);
	virtual ~FXMovieManager();
	virtual void create();

	enum{
   	ID_CLOCKTIME = FXMainWindow::ID_LAST,

	ID_CLIPBOARD_CUT_LP,
	ID_CLIPBOARD_COPY_LP,
	ID_CLIPBOARD_PASTE_LP,
	ID_CLIPBOARD_CUT_RP,
	ID_CLIPBOARD_COPY_RP,
	ID_CLIPBOARD_PASTE_RP,

	ID_FILE_LP,
	ID_FILE_RP,
	ID_AUDIO,
	ID_DROP,
	ID_FULL,
	ID_LOOP,
	ID_PLAY,
	ID_PAUSE,
	ID_STOP,
		
	ID_VOLUME,
	ID_VOLUME_INC,
	ID_VOLUME_DEC,		
	ID_BRIGHTNESS,
	ID_BRIGHTNESS_INC,
	ID_BRIGHTNESS_DEC,
	ID_CONTRAST,
	ID_CONTRAST_INC,
	ID_CONTRAST_DEC,
//	ID_GAMMA,
	ID_HUE,
	ID_HUE_INC,
	ID_HUE_DEC,	
	ID_SATURATION,
	ID_SATURATION_INC,
	ID_SATURATION_DEC,
	
	ID_SPEED,
	ID_AUDIODELAY,
	ID_QUIT,

	ID_SAVELIST,
	ID_OPENLIST,
	ID_LIST,
	ID_TABLE,
	ID_MOVESELUP,
	ID_MOVESELDOWN,
	ID_APPEND_LP,
	ID_APPEND_RP,
	ID_INSERT_LP,
	ID_INSERT_RP,
	ID_EXPORT,
	ID_DELETE,
	ID_SELECTALL,
	ID_SELECTONE,
	ID_CLEAR,
	ID_MAINWINDOW,

	ID_SHOW_FULL_LP,
	ID_SHOW_DIR_LP,
	ID_SHOW_FILE_LP,
	ID_SHOW_FULL_RP,
	ID_SHOW_DIR_RP,
	ID_SHOW_FILE_RP,

	ID_DIRECTORYLIST_LP,
	ID_UPDIRECTORY_LP,
	ID_DIRDELETE_LP,
	ID_NEWDIR_LP,
	ID_DIRRENAME_LP,
	ID_SCANHOST_LP,
	ID_MAPHOST_LP,
	ID_UNMAPHOST_LP,

	ID_DIRECTORYLIST_RP,
	ID_UPDIRECTORY_RP,
	ID_DIRDELETE_RP,
	ID_NEWDIR_RP,
	ID_DIRRENAME_RP,
	ID_SCANHOST_RP,
	ID_MAPHOST_RP,
	ID_UNMAPHOST_RP,

	ID_FILELIST_LP,
	ID_FILELIST_RP,
	ID_FILEDELETE_LP,
	ID_FILEDELETE_RP,
	ID_FILEMOVE_LP,
	ID_FILEMOVE_RP,
	ID_FILECOPY_LP,
	ID_FILECOPY_RP,
	ID_FILESYMLINK_LP,
	ID_FILESYMLINK_RP,
	ID_FILERENAME_LP,
	ID_FILERENAME_RP,

	ID_FILESEARCH_LP,
	ID_FILESEARCH_RP,

	ID_IFILEPLAY_LP,
	ID_IFILEPLAY_RP,

	ID_FILEPLAY_LP,
	ID_FILEPLAY_RP,
	ID_FILEPAUSE_LP,
	ID_FILEPAUSE_RP,
	ID_FILESTOP_LP,
	ID_FILESTOP_RP,
	ID_FILEPREVIEW_LP,
	ID_FILEPREVIEW_RP,
	ID_FORCEFILEPREVIEW_LP,
	ID_FORCEFILEPREVIEW_RP,
	ID_INCFILEPREVIEW_LP,
	ID_INCFILEPREVIEW_RP,
	ID_DECFILEPREVIEW_LP,
	ID_DECFILEPREVIEW_RP,
	ID_CLEARPREVIEW_LP,
	ID_CLEARPREVIEW_RP,
	ID_WIDESCREEN,
	ID_SEEKINCREMENT,

	ID_TERMINAL_LP,
	ID_TERMINAL_RP,
	ID_COMMAND_LP,
	ID_COMMAND_RP,

	ID_MIMETYPE,
	ID_SCANVIRUS_LP,
	ID_SCANVIRUS_RP,
	ID_ARCHIVE_LP,
	ID_ARCHIVE_RP,

	ID_PROPERTIES_LP,
	ID_VIDEO_ASPECT_LP,
	ID_AUDIO_FORMAT_LP,
   	ID_FILE_CREATED_LP,
   	ID_FILE_MODIFIED_LP,
   	ID_FILE_TYPE_LP,
	ID_FILE_MIMETYPE_LP,
	ID_FILE_COMMAND_LP,
   	ID_FILE_LOCATION_LP,
   	ID_FILE_SIZE_LP,
   	ID_FILE_DESC_LP,

	ID_PROPERTIES_RP,
	ID_VIDEO_ASPECT_RP,
	ID_AUDIO_FORMAT_RP,
   	ID_FILE_CREATED_RP,
   	ID_FILE_MODIFIED_RP,
   	ID_FILE_TYPE_RP,
	ID_FILE_MIMETYPE_RP,
	ID_FILE_COMMAND_RP,
   	ID_FILE_LOCATION_RP,
   	ID_FILE_SIZE_RP,
   	ID_FILE_DESC_RP,

	ID_MOVIEINFO_LP,
	ID_MOVIEINFO_RP,

	ID_OPEN_LP,
	ID_OPEN_RP,
   	ID_OPENWITH_LP,
   	ID_OPENWITH_RP,

   	ID_READOWNER_LP,
   	ID_WRITEOWNER_LP,
   	ID_EXECUTEOWNER_LP,
   	ID_READGROUP_LP,
   	ID_WRITEGROUP_LP,
   	ID_EXECUTEGROUP_LP,
   	ID_READOTHER_LP,
   	ID_WRITEOTHER_LP,
   	ID_EXECUTEOTHER_LP,
   	ID_SETUID_LP,
   	ID_SETGID_LP,
   	ID_STICKY_LP,

   	ID_READOWNER_RP,
   	ID_WRITEOWNER_RP,
   	ID_EXECUTEOWNER_RP,
   	ID_READGROUP_RP,
   	ID_WRITEGROUP_RP,
   	ID_EXECUTEGROUP_RP,
   	ID_READOTHER_RP,
   	ID_WRITEOTHER_RP,
   	ID_EXECUTEOTHER_RP,
   	ID_SETUID_RP,
   	ID_SETGID_RP,
   	ID_STICKY_RP,

   	ID_OWNER_LP,
   	ID_OWNER_RP,
   	ID_GROUP_LP,
   	ID_GROUP_RP,

	ID_SIZE_0,
	ID_SIZE_1,
	ID_SIZE_2,
	ID_SIZE_3,
	ID_SIZE_4,
	ID_SIZE_5,
	ID_SIZE_6,
	ID_SIZE_7,
	ID_SIZE_8,
	ID_SIZE_9,
	ID_SIZE_10,
	ID_SIZE_11,
	ID_SIZE_12,
	ID_SIZE_13,
	ID_SIZE_14,
	ID_SIZE_15,
	ID_SIZE_16,
	ID_SIZE_17,
	ID_SIZE_18,
	ID_SIZE_19,
	ID_SIZE_20,
	ID_SIZE_21,
	ID_SIZE_22,
	ID_SIZE_23,
	ID_SIZE_24,
	ID_SIZE_25,

	ID_VIDEO_0,
	ID_VIDEO_1,
	ID_VIDEO_2,
	ID_VIDEO_3,
	ID_VIDEO_4,
	ID_VIDEO_5,
	ID_VIDEO_6,
	ID_VIDEO_7,
	ID_VIDEO_8,
	ID_VIDEO_9,
	ID_LAST,
	};

public:
	// clock
  	long onClock(FXObject*,FXSelector,void*);

	// player button commands
	long onCmdQuit(FXObject *,FXSelector,void *);
	long onCmdFile_lp(FXObject *,FXSelector,void *);
	long onCmdFile_rp(FXObject *,FXSelector,void *);
	long onCmdAudio(FXObject *,FXSelector,void *);
	long onCmdPlay(FXObject *,FXSelector,void *);
	long onCmdPause(FXObject *,FXSelector,void *);
	long onCmdStop(FXObject *,FXSelector,void *);
	long onCmdDrop(FXObject *,FXSelector,void *);
	long onCmdFull(FXObject *,FXSelector,void *);
	long onCmdLoop(FXObject *,FXSelector,void *);
	long onCmdSpeed(FXObject *,FXSelector,void *);
	long onCmdSizeSwitch(FXObject* sender,FXSelector sel,void* ptr);
	long onUpdSizeSwitch(FXObject* sender,FXSelector sel,void* ptr);
	long onCmdVideoSwitch(FXObject* sender,FXSelector sel,void* ptr);
	long onUpdVideoSwitch(FXObject* sender,FXSelector sel,void* ptr);

	// mplayer picture controls
	long onCmdBrightness(FXObject *,FXSelector,void *);
	long onCmdBrightness_inc(FXObject *,FXSelector,void *);
	long onCmdBrightness_dec(FXObject *,FXSelector,void *);
	long onCmdContrast(FXObject *,FXSelector,void *);
	long onCmdContrast_inc(FXObject *,FXSelector,void *);
	long onCmdContrast_dec(FXObject *,FXSelector,void *);
//	long onCmdGamma(FXObject *,FXSelector,void *);
	long onCmdHue(FXObject *,FXSelector,void *);
	long onCmdHue_inc(FXObject *,FXSelector,void *);
	long onCmdHue_dec(FXObject *,FXSelector,void *);
	long onCmdSaturation(FXObject *,FXSelector,void *);
	long onCmdSaturation_inc(FXObject *,FXSelector,void *);
	long onCmdSaturation_dec(FXObject *,FXSelector,void *);
	
	// mplayer audio controls
	long onCmdVolume(FXObject *,FXSelector,void *);
	long onCmdVolume_inc(FXObject *,FXSelector,void *);
	long onCmdVolume_dec(FXObject *,FXSelector,void *);
	long onCmdAudiodelay(FXObject *,FXSelector,void *);

	// table
	long onCmdAppend_lp(FXObject*,FXSelector,void*);
	long onCmdAppend_rp(FXObject*,FXSelector,void*);
	long onCmdInsert_lp(FXObject*,FXSelector,void*);
	long onCmdInsert_rp(FXObject*,FXSelector,void*);
	long onCmdDelete(FXObject*,FXSelector,void*);
	long onCmdMoveSelUp(FXObject*,FXSelector,void*);
	long onCmdMoveSelDown(FXObject*,FXSelector,void*);
	long onCmdExport(FXObject*,FXSelector,void*);
	long onCmdSelectAll(FXObject*,FXSelector,void*);
	long onCmdSelectOne(FXObject*,FXSelector,void*);
	long onCmdClear(FXObject*,FXSelector,void*);
	long onListRightMouse(FXObject*,FXSelector,void* ptr);
	long onCmdPutBack(FXObject*,FXSelector,void*);
  	long onUpdSelectedTable(FXObject*,FXSelector,void*);
	long onCmdSavePlaylist(FXObject*,FXSelector,void*);
	long onCmdOpenPlaylist(FXObject*,FXSelector,void*);

	// switcher
  	long onCmdShowPanel_lp(FXObject* sender,FXSelector sel,void* ptr);
  	long onCmdShowPanel_rp(FXObject* sender,FXSelector sel,void* ptr);

	// left directory list
  	long onCmdDirectory_lp(FXObject*,FXSelector,void*);
  	long onCmdUpDirectory_lp(FXObject*,FXSelector,void*);
  	long onCmdNewDir_lp(FXObject*,FXSelector,void*);
	long onCmdDirRename_lp(FXObject*,FXSelector,void*);
  	long onUpdNewDir_lp(FXObject*,FXSelector,void*);
  	long onCmdDirDelete_lp(FXObject*,FXSelector,void*);
	long onDirListPopup_lp(FXObject*,FXSelector,void*);
  	long onCmdScanHost_lp(FXObject*,FXSelector,void*);
  	long onCmdMapHost_lp(FXObject*,FXSelector,void*);
  	long onCmdUnmapHost_lp(FXObject*,FXSelector,void*);
	// right directory list
  	long onCmdDirectory_rp(FXObject*,FXSelector,void*);
  	long onCmdUpDirectory_rp(FXObject*,FXSelector,void*);
  	long onCmdNewDir_rp(FXObject*,FXSelector,void*);
	long onCmdDirRename_rp(FXObject*,FXSelector,void*);
  	long onUpdNewDir_rp(FXObject*,FXSelector,void*);
  	long onCmdDirDelete_rp(FXObject*,FXSelector,void*);
	long onDirListPopup_rp(FXObject*,FXSelector,void*);
  	long onCmdScanHost_rp(FXObject*,FXSelector,void*);
  	long onCmdMapHost_rp(FXObject*,FXSelector,void*);
  	long onCmdUnmapHost_rp(FXObject*,FXSelector,void*);

	// left file list
	long onFileListPopup_lp(FXObject*,FXSelector,void*);
	long onCmdFileListDC_lp(FXObject*,FXSelector,void*);
	long onCmdFileListC_lp(FXObject*,FXSelector,void*);
	long onCmdFileCopy_lp(FXObject*,FXSelector,void*);
	long onCmdFileSymlink_lp(FXObject*,FXSelector,void*);
	long onCmdFileMove_lp(FXObject*,FXSelector,void*);
	long onCmdFileRename_lp(FXObject*,FXSelector,void*);
	long onCmdFileDelete_lp(FXObject*,FXSelector,void*);
	long onUpdSelected_lp(FXObject*,FXSelector,void*);
  	long onUpdSelectedVideoFile_lp(FXObject*,FXSelector,void*);
  	long onUpdSelectedVideoAudioFile_lp(FXObject*,FXSelector,void*);
  	long onUpdSelectedVideoAudioImageFile_lp(FXObject*,FXSelector,void*);
  	long onUpdSelectedImageFile_lp(FXObject*,FXSelector,void*);
	long onCmdFilePlay_lp(FXObject *o,FXSelector,void*);
	long onCmdFilePause_lp(FXObject*,FXSelector,void*);
	long onCmdFileStop_lp(FXObject *,FXSelector,void *);
	long onCmdImagePlay_lp(FXObject*,FXSelector,void*);
	// right file list
	long onFileListPopup_rp(FXObject*,FXSelector,void*);
	long onCmdFileListDC_rp(FXObject*,FXSelector,void*);
	long onCmdFileListC_rp(FXObject*,FXSelector,void*);
	long onCmdFileCopy_rp(FXObject*,FXSelector,void*);
	long onCmdFileMove_rp(FXObject*,FXSelector,void*);
	long onCmdFileRename_rp(FXObject*,FXSelector,void*);
	long onCmdFileSymlink_rp(FXObject*,FXSelector,void*);
	long onCmdFileDelete_rp(FXObject*,FXSelector,void*);
	long onUpdSelected_rp(FXObject*,FXSelector,void*);
  	long onUpdSelectedVideoFile_rp(FXObject*,FXSelector,void*);
  	long onUpdSelectedVideoAudioFile_rp(FXObject*,FXSelector,void*);
  	long onUpdSelectedVideoAudioImageFile_rp(FXObject*,FXSelector,void*);
  	long onUpdSelectedImageFile_rp(FXObject*,FXSelector,void*);
	long onCmdFilePlay_rp(FXObject *o,FXSelector,void*);
	long onCmdFilePause_rp(FXObject*,FXSelector,void*);
	long onCmdFileStop_rp(FXObject *,FXSelector,void *);
	long onCmdImagePlay_rp(FXObject*,FXSelector,void*);

	// search engine
	long onCmdFileSearch_lp(FXObject*,FXSelector,void*);
	long onCmdFileSearch_rp(FXObject*,FXSelector,void*);

	// movie preview
	long onCmdFilePreview_lp(FXObject*,FXSelector,void*);
	long onCmdFilePreview_rp(FXObject*,FXSelector,void*);
	long onCmdForceFilePreview_lp(FXObject*,FXSelector,void*);
	long onCmdForceFilePreview_rp(FXObject*,FXSelector,void*);
	long onCmdIncFilePreview_lp(FXObject*,FXSelector,void*);
	long onCmdIncFilePreview_rp(FXObject*,FXSelector,void*);
	long onCmdDecFilePreview_lp(FXObject*,FXSelector,void*);
	long onCmdDecFilePreview_rp(FXObject*,FXSelector,void*);
	long onCmdClearPreview_lp(FXObject*,FXSelector,void*);
	long onCmdClearPreview_rp(FXObject*,FXSelector,void*);

	long onCmdWideScreen(FXObject*,FXSelector,void*);
	long onUpdSeekIncrement(FXObject*,FXSelector,void*);

	long onCmdTerminal_lp(FXObject*,FXSelector,void*);
	long onCmdTerminal_rp(FXObject*,FXSelector,void*);

	long onCmdCommand_lp(FXObject*,FXSelector,void*);
	long onCmdCommand_rp(FXObject*,FXSelector,void*);

	long onCmdScanVirus_lp(FXObject*,FXSelector,void*);
	long onCmdScanVirus_rp(FXObject*,FXSelector,void*);

	long onCmdArchive_lp(FXObject*,FXSelector,void*);
	long onCmdArchive_rp(FXObject*,FXSelector,void*);

	// properties dialog
  	long onCmdProperties_lp(FXObject*,FXSelector,void*);
  	long onUpdMovieAspect_lp(FXObject*,FXSelector,void*);
  	long onUpdAudioFormat_lp(FXObject*,FXSelector,void*);
  	long onUpdCreatedTime_lp(FXObject*,FXSelector,void*);
  	long onUpdModifiedTime_lp(FXObject*,FXSelector,void*);
  	long onUpdFileType_lp(FXObject*,FXSelector,void*);
  	long onUpdFileMimeType_lp(FXObject*,FXSelector,void*);
  	long onUpdFileCommand_lp(FXObject*,FXSelector,void*);	
  	long onUpdFileLocation_lp(FXObject*,FXSelector,void*);
  	long onUpdFileSize_lp(FXObject*,FXSelector,void*);
  	long onUpdFileDesc_lp(FXObject*,FXSelector,void*);

  	long onCmdProperties_rp(FXObject*,FXSelector,void*);
  	long onUpdMovieAspect_rp(FXObject*,FXSelector,void*);
  	long onUpdAudioFormat_rp(FXObject*,FXSelector,void*);
  	long onUpdCreatedTime_rp(FXObject*,FXSelector,void*);
  	long onUpdModifiedTime_rp(FXObject*,FXSelector,void*);
  	long onUpdFileType_rp(FXObject*,FXSelector,void*);
  	long onUpdFileMimeType_rp(FXObject*,FXSelector,void*);
  	long onUpdFileCommand_rp(FXObject*,FXSelector,void*);	
  	long onUpdFileLocation_rp(FXObject*,FXSelector,void*);
  	long onUpdFileSize_rp(FXObject*,FXSelector,void*);
  	long onUpdFileDesc_rp(FXObject*,FXSelector,void*);

  	long onCmdMovieInfo_lp(FXObject*,FXSelector,void*);
  	long onCmdMovieInfo_rp(FXObject*,FXSelector,void*);

  	long onCmdFilemode_lp(FXObject*,FXSelector,void*);
  	long onUpdFilemode_lp(FXObject*,FXSelector,void*);
  	long onCmdFilemode_rp(FXObject*,FXSelector,void*);
  	long onUpdFilemode_rp(FXObject*,FXSelector,void*);
  	long onUpdOwner_lp(FXObject*,FXSelector,void*);
  	long onUpdOwner_rp(FXObject*,FXSelector,void*);
  	long onUpdGroup_lp(FXObject*,FXSelector,void*);
  	long onUpdGroup_rp(FXObject*,FXSelector,void*);

	// mimetype dialog
  	long onCmdMimeType(FXObject*,FXSelector,void*);

  	long onCmdOpen_lp(FXObject*,FXSelector,void*);
  	long onCmdOpen_rp(FXObject*,FXSelector,void*);
  	long onCmdOpenWith_lp(FXObject*,FXSelector,void*);
  	long onCmdOpenWith_rp(FXObject*,FXSelector,void*);
  	long onUpdItemFound_lp(FXObject*,FXSelector,void*);
  	long onUpdItemFound_rp(FXObject*,FXSelector,void*);

	// clipboard actions
	long onClipboardLost(FXObject* sender,FXSelector sel,void* ptr);
	long onClipboardGained(FXObject* sender,FXSelector sel,void* ptr);
	long onClipboardRequest(FXObject* sender,FXSelector sel,void* ptr);
	long onCmdCopyCut_lp(FXObject*,FXSelector sel,void*);
	long onCmdPaste_lp(FXObject*,FXSelector sel,void*);
	long onCmdCopyCut_rp(FXObject*,FXSelector sel,void*);
	long onCmdPaste_rp(FXObject*,FXSelector sel,void*);
	long onUpdPaste(FXObject* o,FXSelector sel,void*);

};

#endif
