/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008-2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                                 v 6.6                    *
*********************************************************************************
* Id: fxplayer_clock.h,                                2008/01/01               *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/


#ifndef FXPLAYER_CLOCK_H
#define FXPLAYER_CLOCK_H

#include "config.h"

#ifdef ENABLE_PLAYERS // at least one

/* no AV correction is done if too big error */
#define AV_NOSYNC_THRESHOLD             10.0

#if HAVE_LIBAVUTIL
 #include <libavutil/time.h>
#endif

#if HAVE_LIBAVFORMAT
 #include <libavformat/avformat.h>
#endif


typedef struct Clock {
  double          pts;            ///< clock base
  double          pts_drift;      ///< clock base minus time at which we updated the clock
  double          last_updated;
  double          speed;
  int             serial;         ///< clock is based on a packet with this serial
  int             paused;
  int             *queue_serial;  ///< pointer to the current packet queue serial, used for obsolete clock detection
} Clock;


double get_clock(Clock *c);

void set_clock_at(Clock *c, double pts, int serial, double time);

void set_clock(Clock *c, double pts, int serial);

void set_clock_speed(Clock *c, double speed);

void init_clock(Clock *c, int *queue_serial);

void sync_clock_to_slave(Clock *c, Clock *slave);


#endif /* ENABLE_PLAYERS */

#endif /* FXPLAYER_CLOCK_H */
