/********************************************************************************
*                                                                               *
*                      F X   M O V I E   M A N A G E R                          *
*                                                                               *
*********************************************************************************
* Copyright(C) 2008-2014 by Luigi Ziviani <ziviani_luigi@yahoo.it>.             *
* All Rights Reserved.                                 v 6.5                    *
*********************************************************************************
* Id: fxplayer_queue.h,                                2008/01/01               *
*********************************************************************************
* This file is part of FXMOVIEMANAGER                                           *
*                                                                               *
* FXMOVIEMANAGER is free software; you can redistribute it and/or modify        *
* it under the terms of the GNU General Public License as published by          *
* the Free Software Foundation; either version 3 of the License, or             *
* (at your option) any later version.                                           *
*                                                                               *
* FXMOVIEMANAGER is distributed in the hope that it will be useful,             *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
* GNU General Public License for more details.                                  *
*                                                                               *
* You should have received a copy of the GNU General Public License             *
* along with this program; if not, write to the Free Software                   *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA     * 
********************************************************************************/


#ifndef FXPLAYER_QUEUE_H
#define FXPLAYER_QUEUE_H

#include "config.h"

#ifdef ENABLE_PLAYERS // at least one

#if HAVE_LIBSDL
#include <SDL/SDL.h>
#include <SDL/SDL_thread.h>
#endif

#if HAVE_LIBSDL2
#include <SDL2/SDL.h>
#include <SDL2/SDL_thread.h>
//#include <SDL2/SDL_syswm.h>
#endif

#ifdef HAVE_LIBAVFORMAT
 #include <libavformat/avformat.h>
#endif

typedef struct LocalAVPacketList {
  AVPacket pkt;
  struct LocalAVPacketList *next;
  int             serial;
} LocalAVPacketList;

typedef struct PacketQueue {
  LocalAVPacketList   *first_pkt; 
  LocalAVPacketList   *last_pkt;
  int             quit;
  int             nb_packets;
  int             size;
  int             serial;
  SDL_mutex       *mutex;
  SDL_cond        *cond;
} PacketQueue;


AVPacket flush_pkt;
// static PACKET QUEUE
//static int packet_queue_put(PacketQueue *q, AVPacket *pkt);

// packet queue store packet
int packet_queue_put_private(PacketQueue *q, AVPacket *pkt);

// packet queue duplicate
int packet_queue_put(PacketQueue *q, AVPacket *pkt);

// packet queue initialize
void packet_queue_init(PacketQueue *q);

// packet queue flush
void packet_queue_flush(PacketQueue *q);

// packet queue destroy
void packet_queue_destroy(PacketQueue *q);

// packet queue lock
void packet_queue_quit(PacketQueue *q);

// packet queue start
void packet_queue_start(PacketQueue *q);

// return -1 if aborted, 0 if no packet and 1 if packet.
int packet_queue_get(PacketQueue *q, AVPacket *pkt, int block, int *serial);


#endif /* ENABLE_PLAYERS */

#endif /* FXPLAYER_QUEUE_H */
